<?php
/**
 * Javascripts functions 
 *
 * @package Flatnux_functions
 * 
 * @author Alessandro Vernassa <speleoalex@gmail.com>
 * @copyright Copyright (c) 2003-2005
 * @license http://opensource.org/licenses/gpl-license.php GNU General Public License
 */
/**
 * Dichiara una funzione JS per il pannello dei pulsanti BBCODES
 *
 * Dichiara una funzione JS che viene utilizzata dal pannello dei
 * pulsanti BBCODES per inserire il testo corretto nell'area di testo
 * indicata come terzo parametro.
 *
 * @author Simone Vellei <simone_vellei@users.sourceforge.net>
 * @author Marco Segato <segatom@users.sourceforge.net> | 20050906: added parameter 'area' in JS function
 * @author Bjrn Splinter <insites@gmail.com> | 20050912: removed additional chars inserted before and after tag1/tag2 in 'if(document.selection) {}
 * @author Alessandro Vernassa <speleoalex@gmail.com>
 *
 */
function bbcodes_js()
{
	echo "<script type='text/javascript'>
function insertTags(tag1, tag2, area) {
	var txta = document.getElementsByName(area)[0];
	txta.focus();
	if (document.selection) {
		var sel  = document.selection.createRange();
		sel.text = tag2
			? tag1 + sel.text + tag2
			: tag1;
	}
	else if (txta.selectionStart != undefined) {
		var before = txta.value.substring(0, txta.selectionStart);
		var sel    = txta.value.substring(txta.selectionStart, txta.selectionEnd);
		var after  = txta.value.substring(txta.selectionEnd, txta.textLength);
		txta.value = tag2
			? before + tag1 + sel + tag2 + after
			: before + \"\" + tag1 + \"\" + after;
	}
}
</script>";
}
/**
 * Crea il pannello dei pulsanti BBCODES
 *
 * Crea il pannello dei pulsanti BBCODES per inserire il testo corretto
 * nell'area di testo indicata come parametro.
 *
 * @author Simone Vellei <simone_vellei@users.sourceforge.net>
 * @author Marco Segato <segatom@users.sourceforge.net> | 20050906: added parameter 'area' in JS function
 * @author Bjrn Splinter <insites@gmail.com> | 20050912: added variable 'prepath', changed some '' to "" to prevent IE script errors
 * @author Alessandro Vernassa <speleoalex@gmail.com>
 *
 * @param string $area Area di testo in cui inserire i BBCODES
 * @param string $what 'formatting' per creare il pannello con i tasti di formattazione testo, 'emoticons' per le emoticons
 */
function bbcodes_panel($area, $what)
{
	global $_FN;
	$lang = $_FN['lang'];
	// verifico provenienza della chiamata e adatto i richiami alle directories
	// stampo la parte di pannello selezionata
	switch ( $what )
	{
		case "formatting" :
?><img
				onclick="javascript:insertTags('[b]', '[/b]', '<?php echo $area ?>')"
				onmouseover="document.getElementsByName('<?php echo $area ?>')[0].focus()"
				src="<?php
			echo fromtheme("images/emoticon/bold.png");
?>"
			border="0" alt="bold" title="bold" style="cursor: pointer;" />
		<img
			onclick="javascript:insertTags('[i]', '[/i]', '<?php echo $area ?>')"
			onmouseover="document.getElementsByName('<?php echo $area ?>')[0].focus()"
			src="<?php
			echo fromtheme("images/emoticon/italic.png");
?>"
			border="0" alt="italic" title="italic" style="cursor: pointer;" />
		<img
			onclick="javascript:insertTags('[quote]', '[/quote]', '<?php echo $area ?>')"
			onmouseover="document.getElementsByName('<?php echo $area ?>')[0].focus()"
			src="<?php
			echo fromtheme("images/emoticon/quote.png");
?>"
			border="0" alt="quote" title="quote" style="cursor: pointer;" />
		<img
			onclick="javascript:insertTags('[code]', '[/code]', '<?php echo $area ?>')"
			onmouseover="document.getElementsByName('<?php echo $area ?>')[0].focus()"
			src="<?php
			echo fromtheme("images/emoticon/code.png");
?>"
			border="0" alt="code" title="code" style="cursor: pointer;" />
<?php
			// solo l'amministratore puo' inserire immagini
			if ( isadmin ( ) )
			{
?><img
				onclick="javascript:insertTags('[img]', '[/img]', '<?php echo $area ?>')"
				onmouseover="document.getElementsByName('<?php echo $area ?>')[0].focus()"
				src="<?php
				echo fromtheme("images/emoticon/image.png");
?>"
				border="0" alt="image" title="image" style="cursor: pointer;" /><?php
			}
?>
		<img
			onclick="javascript:insertTags('[red]', '[/red]', '<?php echo $area ?>')"
			onmouseover="document.getElementsByName('<?php echo $area ?>')[0].focus()"
				src="<?php
			echo fromtheme("images/emoticon/red.png");
?>"
			border="0" alt="red" title="red" style="cursor: pointer;" />
		<img
			onclick="javascript:insertTags('[green]', '[/green]', '<?php echo $area ?>')"
			onmouseover="document.getElementsByName('<?php echo $area ?>')[0].focus()"
			src="<?php
			echo fromtheme("images/emoticon/green.png");
?>"
			border="0" alt="green" title="green" style="cursor: pointer;" />
		<img
			onclick="javascript:insertTags('[blue]', '[/blue]', '<?php echo $area ?>')"
			onmouseover="document.getElementsByName('<?php echo $area ?>')[0].focus()"
			src="<?php
			echo fromtheme("images/emoticon/blue.png");
?>"
			border="0" alt="blue" title="blue" style="cursor: pointer;" />
		<img
			onclick="javascript:insertTags('[pink]', '[/pink]', '<?php echo $area ?>')"
			onmouseover="document.getElementsByName('<?php echo $area ?>')[0].focus()"
			src="<?php
			echo fromtheme("images/emoticon/pink.png");
?>"
			border="0" alt="pink" title="pink" style="cursor: pointer;" />
		<img
			onclick="javascript:insertTags('[yellow]', '[/yellow]', '<?php echo $area ?>')"
			onmouseover="document.getElementsByName('<?php echo $area ?>')[0].focus()"
			src="<?php
			echo fromtheme("images/emoticon/yellow.png");
?>"
			border="0" alt="yellow" title="yellow" style="cursor: pointer;" />
		<img
			onclick="javascript:insertTags('[cyan]', '[/cyan]', '<?php echo $area ?>')"
			onmouseover="document.getElementsByName('<?php echo $area ?>')[0].focus()"
			src="<?php
			echo fromtheme("images/emoticon/cyan.png");
?>"
			border="0" alt="cyan" title="cyan" style="cursor: pointer;" />
		<img
			onclick="javascript:insertTags('[url]', '[/url]', '<?php echo $area ?>')"
			onmouseover="document.getElementsByName('<?php echo $area ?>')[0].focus()"
			src="<?php
			echo fromtheme("images/emoticon/url.png");
?>"
			border="0" alt="url" title="url" style="cursor: pointer;" />
		<img
			onclick="javascript:insertTags('[wp lang=<?php echo $lang ?>]', '[/wp]', '<?php echo $area ?>')"
			onmouseover="document.getElementsByName('<?php echo $area ?>')[0].focus()"
			src="<?php
			echo fromtheme("images/emoticon/wikipedia.png");
?>"
			border="0" alt="wikipedia" title="wikipedia" style="cursor: pointer;" />
	<?php
			break;
		case "emoticons" :
	?>
		<img
			onclick="javascript:insertTags('[:)]', '', '<?php echo $area ?>')"
			onmouseover="document.getElementsByName('<?php echo $area ?>')[0].focus()"
			src="<?php
			echo fromtheme("images/emoticon/01.png");
	?>"
			border="0" alt="Happy" style="cursor: pointer;" />
		<img
			onclick="javascript:insertTags('[:(]', '', '<?php echo $area ?>')"
			onmouseover="document.getElementsByName('<?php echo $area ?>')[0].focus()"
			src="<?php
			echo fromtheme("images/emoticon/02.png");
	?>"
			border="0" alt="Triste" style="cursor: pointer;" />
		<img
			onclick="javascript:insertTags('[:o]', '', '<?php echo $area ?>')"
			onmouseover="document.getElementsByName('<?php echo $area ?>')[0].focus()"
			src="<?php
			echo fromtheme("images/emoticon/03.png");
	?>"
			border="0" alt="sorpresa" style="cursor: pointer;" />
		<img
			onclick="javascript:insertTags('[:p]', '', '<?php echo $area ?>')"
			onmouseover="document.getElementsByName('<?php echo $area ?>')[0].focus()"
			src="<?php
			echo fromtheme("images/emoticon/04.png");
	?>"
			border="0" alt="linguaccia" style="cursor: pointer;" />
		<img
			onclick="javascript:insertTags('[:D]', '', '<?php echo $area ?>')"
			onmouseover="document.getElementsByName('<?php echo $area ?>')[0].focus()"
			src="<?php
			echo fromtheme("images/emoticon/05.png");
	?>"
			border="0" alt="risata" style="cursor: pointer;" />
		<img
			onclick="javascript:insertTags('[:!]', '', '<?php echo $area ?>')"
			onmouseover="document.getElementsByName('<?php echo $area ?>')[0].focus()"
			src="<?php
			echo fromtheme("images/emoticon/06.png");
	?>"
			border="0" alt="indifferente" style="cursor: pointer;" />
		<img
			onclick="javascript:insertTags('[:O]', '', '<?php echo $area ?>')"
			onmouseover="document.getElementsByName('<?php echo $area ?>')[0].focus()"
			src="<?php
			echo fromtheme("images/emoticon/07.png");
	?>"
			border="0" alt="sbalordito" style="cursor: pointer;" />
		<img
			onclick="javascript:insertTags('[8)]', '', '<?php echo $area ?>')"
			onmouseover="document.getElementsByName('<?php echo $area ?>')[0].focus()"
			src="<?php
			echo fromtheme("images/emoticon/08.png");
	?>"
			border="0" alt="fighetto" style="cursor: pointer;" />
		<img
			onclick="javascript:insertTags('[;)]', '', '<?php echo $area ?>')"
			onmouseover="document.getElementsByName('<?php echo $area ?>')[0].focus()"
			src="<?php
			echo fromtheme("images/emoticon/09.png");
	?>"
			border="0" alt="occhiolino" style="cursor: pointer;" />
	<?php
			break;
	}
}
/**
 * genera javascript per creare reindirizzare una pagina
 * @param string where
 * 
 */
function jsredirect($where)
{
	//dprint_r($_POST);
	//die ("<a href=\"".$where."\">$where</a>");

	echo "\n<script language=\"javascript\">
				window.location='$where';
		</script>\n";
}
/**
 * genera javascript per creare un alert
 * @param string message
 * 
 */
function jsalert($message)
{
	echo "\n<script language=\"javascript\">";
	echo "\n setTimeout(function(){alert(\"" . str_replace("\n", "\\n", addslashes($message)) . "\",0)});";
	echo "\n</script>\n";
}
/**
 * Genera una finestra
 * @param string message
 * 
 */
function fn_popup($message)
{
	echo "\n<div style=\"position:absolute;border:1px solid red;color:#ffffff;background-color:#fafafa\">";
	echo "\n $message";
	echo "\n</div>\n";
}
?>