<?php
/**
 * Theme functions
 * 
 * @package Flatnux_theme_functions
 * 
 */
if ( strpos(strtolower($_SERVER['SCRIPT_NAME']),strtolower(basename(__FILE__))) )
{
	header("Location: ../../index.php");
	die("...");
}
global $_FN;
global $forumback,$forumborder;
$_FN['table_background'] = &$forumback;
$_FN['table_border'] = &$forumborder;
if ( $forumback == "" && $forumborder == "" )
{
	$forumback = "ffffff";
	$forumborder = "000000";
}
require_once ("themes/{$_FN['theme']}/theme.php");
/* ------- Funzioni ridefinibili da theme.php-------------- */
if (  !function_exists("showmotd") )
{
	/**
	 * Visualizza il motd
	 * @author Alessandro Vernassa <speleoalex@gmail.com>
	 * */
	function showmotd()
	{
		global $_FN;
		if ( file_get_contents("{$_FN['datadir']}/motd." . $_FN['lang'] . ".php") == "" )
			return;
		if ( function_exists("FN_OpenMotd") && function_exists("FN_CloseMotd") )
			FN_OpenMotd();
		else
			OpenTable();
		if ( file_exists("themes/{$_FN['theme']}/images/motd.png") )
			echo "<img src='themes/{$_FN['theme']}/images/motd.png' align='left' hspace='10' vspace='10' alt='Motd' />";
		echo local_to_abs("{$_FN['datadir']}/motd." . $_FN['lang'] . ".php");
		if ( isadmin() && $_FN['fneditmode'] != 0 )
		{
			echo "<br /><span class=\"flatnukeadmin\"><a href=\"index.php?opindex=modcont&amp;file={$_FN['datadir']}/motd.{$_FN['lang']}.php&amp;from=index.php\">" . _MODIFICA . "</a></span>";
		}
		if ( function_exists("FN_OpenMotd") && function_exists("FN_CloseMotd") )
			FN_CloseMotd();
		else
			CloseTable();
	}
}
if (  !function_exists("create_menu") )
{
	/**
	 * Crea il menu principale
	 *
	 * Crea un blocco contenente il menu principale elencando tutte le directories
	 * che in <i>/sections/</i> non iniziano con "none_":
	 * - prima vengono, in ordine alfabetico, le directories che iniziano
	 * con un carattere (es: Prova);
	 * - di seguito, in ordine crescente, quelle che iniziano con una coppia
	 * di numeri (es: 03_Prova).
	 *
	 * @author Simone Vellei <simone_vellei@users.sourceforge.net>
	 * @author Alessandro Vernassa <speleoalex@gmail.com>
	 */
	function create_menu()
	{
		global $_FN;
		$title = "Menu";
		OpenBlock("themes/{$_FN['theme']}/images/menu.png",$title);
		$modlist = list_sections_translated("sections"); // return array width title - link
		$tl = "";
		if ( $_FN['lang'] != $_FN['lang_default'] )
			$tl = "&amp;lang={$_FN['lang']}";
		foreach ( $modlist as $modl )
		{
			$link = get_section_id($modl['link']);
			$title = $modl['title'];
			$accesskey = $modl['accesskey'];
			if ( $accesskey != "" )
				$accesskey = "accesskey='$accesskey'";
			echo "<a $accesskey href='" . fn_rewritelink("index.php?mod=$link$tl") . "'>$title</a><br />\n";
		}
		CloseBlock();
		echo "<br />";
	}
}
if (  !function_exists("create_h_menu") )
{
	/**
	 * Crea il menu principale orizzontale
	 *
	 * @param string $separator separatore voci
	 * @author Alessandro Vernassa <speleoalex@gmail.com>
	 */
	function create_h_menu($separator = "|")
	{
		global $_FN;
		$modlist = list_sections_translated("sections"); // return array width title - link
		$i = count($modlist);
		//serve per indicizzare tutte le lingue
		$tl = ($_FN['lang'] != $_FN['lang_default']) ? "&amp;lang={$_FN['lang']}" : "";
		foreach ( $modlist as $modl )
		{
			$link = get_section_id($modl['link']);
			$title = $modl['title'];
			$accesskey = $modl['accesskey'];
			if ( $accesskey != "" )
				$accesskey = "accesskey='$accesskey'";
			if (  --$i == 0 )
				$separator = "";
			echo "<a $accesskey href=\"" . fn_rewritelink("index.php?mod=$link$tl") . "\">$title</a>$separator\n";
		}
	}
}
if (  !function_exists("create_blocks") )
{
	/**
	 * Visualizza i blocchi laterali
	 *
	 * Visualizza il contenuto dei blocchi laterali presenti nelle directories
	 * <i>/blocks/dx/</i> oppure <i>/blocks/sx/</i> a seconda del parametro passato;
	 * non vengono stampati i blocchi che iniziano per "none_".
	 *
	 * @author Simone Vellei <simone_vellei@users.sourceforge.net>
	 * @author Alessandro Vernassa <speleoalex@gmail.com>
	 * @param string $edge Lato dei blocchi da stampare
	 *
	 */
	function create_blocks($edge, $sep = "<br />")
	{
		global $_FN;
		if (  !file_exists('blocks/' . $edge) )
		{
			mkdir('blocks/' . $edge);
			return;
		}
		$handle = opendir('blocks/' . $edge);
		if ( $handle === false )
			return;
		$modlist = array();
		while (false !== ($file = readdir($handle)))
		{
			if (  !is_dir("blocks/$edge/$file") && (preg_match('/.html$/s',$file) or preg_match('/.php$/s',$file) or preg_match('/.menu$/s',$file)) &&  !stristr($file,"none_") )
			{
				$modlist[] = $file;
			}
		}
		closedir($handle);
		fn_natsort($modlist);
		foreach ( $modlist as $kk=>$mod )
		{
			$ext = get_file_extension($mod);
			$tmp = preg_replace('/\.' . $ext . '$/s','',$mod);
			$tmp = preg_replace("/^[0-9]+_|^none_/i","",$tmp);
			$title = str_replace("_","&nbsp;",$tmp);
			$filelang = "blocks/$edge/" . preg_replace("/^[0-9]+_|^none_/si","",$mod) . ".xml";
			//echo "'$filelang'";
			if ( file_exists($filelang) )
			{
				$title = getLang($filelang,$title);
			}
			if ( ob_start() )
			{
				if ( preg_match('/.php$/',$mod) )
					fn_include("blocks/$edge/$mod");
				elseif ( preg_match('/.menu$/',$mod) )
				{
					$params = explode(",",file_get_contents("blocks/$edge/$mod"));
					//   fn_print_menu($path, $menu_recursive, $show_icons, $menu_recursive_onlyselected)
					echo fn_print_menu("sections/" . find_section($params[0]),$params[1],$params[2],$params[3],$params[4]);
				}
				else
				{
					echo local_to_abs("blocks/$edge/$mod");
				}
				$string = ob_get_contents();
				ob_end_clean();
			}
			// se il blocco e' vuoto esco
			if ( $string != "" )
			{
				$img = fromtheme("images/block.png");
				OpenBlock("$img",$title);
				echo "$string";
				//ripristino mod nel caso venga cambiato dal blocco
				$mod = $modlist[$kk];
				//dprint_r($mod);
				if ( isadmin() && $_FN['fneditmode'] != 0 )
					echo "<br /><span class=\"flatnukeadmin\"><a href=\"index.php?opindex=modcont&amp;file=blocks/$edge/$mod&amp;from=index.php\">" . _MODIFICA . "</a></span>";
				CloseBlock();
				echo "$sep";
			}
		}
	}
}
if (  !function_exists("FN_CreateSubmenu") )
{
	/**
	 * @name FN_CreateSubmenu
	 * Visualizza l' elenco delle sottosezioni
	 * */
	function FN_CreateSubmenu()
	{
		global $_FN;
		$section = $_FN['vmod'];
		$modlist = list_sections_translated('sections/' . $section);
		//if (count ($modlist)==0)
		//	$modlist = list_sections_translated ( 'sections/' . dirname($section) );
		if ( count($modlist) > 0 )
		{
			echo "<br /><br />";
			OpenTable();
			foreach ( $modlist as $modl )
			{
				$link = $modl['link'];
				$linkh = get_section_id($modl['link']);
				$title = $modl['title'];
				$accesskey = $modl['accesskey'];
				if ( $accesskey != "" )
					$accesskey = "accesskey='$accesskey'";
				echo "\n<img src='" . fromtheme("images/subsection.png") . "' alt='Subsection' />&nbsp;<a $accesskey href=\"" . fn_rewritelink("index.php?mod=$linkh") . "\">$title</a><br />";
			}
			CloseTable();
		}
	}
}
if (  !function_exists("FN_SectionFooter") )
{
	/**
	 * @name FN_SectionFooter
	 * print section footer
	 * */
	function FN_SectionFooter()
	{
		$options = "";
		$prefix = "?";
		foreach ( $_GET as $key=>$value )
		{
			$value = rawurlencodepath(getparam($value,PAR_NULL,SAN_HTML));
			$key = getparam($key,PAR_NULL,SAN_HTML);
			$options .= $prefix . "$key=$value";
			$prefix = "&amp;";
		}
		echo "<div style=\"text-align:right\"><a onclick=\"window.open(this.href);return false;\" href=\"print.php$options\" >";
		echo "<img src=\"" . fromtheme("images/print.png") . "\" style=\"border:0px\" alt=\"print\" />";
		echo "</a></div>";
	}
}
if (  !function_exists("FN_CreateNavbar") )
{
	/**
	 * Create section navbar
	 *
	 * @param string $tree
	 * @param string $title
	 * @return string navbar title
	 */
	function FN_CreateNavbar($tree, $title)
	{
		$tit = "";
		for ( $i = 0;$i < sizeof($tree);$i++  )
		{
			$mypath = "";
			for ( $j = 0;$j <= $i;$j++  )
			{
				if ( $i > 0 and ($j != $i) )
				{
					$mypath .= $tree[$j] . "/";
				}
				else
				{
					$mypath .= $tree[$j];
				}
			}
			$tmp = $title[$i];
			if ( $i != (sizeof($tree) - 1) )
			{
				$accesskey = getaccesskey($tmp,$mypath);
				$tit .= "<a accesskey=$accesskey href='index.php?mod=$mypath'>$tmp</a> &#187;&nbsp;";
			}
			else
			{
				$tit .= "<b>$tmp</b>";
			}
		}
		return $tit;
	}
}
if (  !function_exists('FN_OpenSection') )
{
	/**
	 * FN_OpenSection
	 * open section
	 * @param string $title
	 * */
	function FN_OpenSection($title)
	{
		OpenTableTitle($title);
	}
}
if (  !function_exists('FN_CloseSection') )
{
	/**
	 * Close a section
	 *
	 */
	function FN_CloseSection()
	{
		FN_SectionFooter();
		FN_CreateSubmenu();
		CloseTableTitle();
	}
}
if (  !function_exists("OpenBlock") )
{
	/**
	 * Open block
	 *
	 * @param string $image
	 * @param string $title
	 */
	function OpenBlock($image, $title)
	{
		if ( $image != "" )
		{
			$title = "<img src=\"$image\" alt=\"\"/>&nbsp;$title";
		}
		OpenTableTitle($title);
	}
}
if (  !function_exists("CloseBlock") )
{
	/**
	 * close block
	 *
	 * @param string $image
	 * @param string $title
	 */
	function CloseBlock($image = "", $title = "")
	{
		if ( $image != "" )
		{
			$title = "<img src=\"$image\" alt=\"\"/>&nbsp;$title";
		}
		CloseTableTitle($title);
	}
}
if (  !function_exists("FN_OpenNews") )
{
	/**
	 * Open a news
	 *
	 * @param string $title
	 */
	function FN_OpenNews($title)
	{
		echo "<br />";
		OpenTableTitle($title);
	}
}
if (  !function_exists("FN_CloseNews") )
{
	/**
	 * Close a news
	 *
	 * @param unknown_type $title
	 */
	function FN_CloseNews($title = "")
	{
		CloseTableTitle($title);
	}
}
if (  !function_exists("OpenTableTitle") )
{
	/**
	 * open table with title
	 *
	 * @param string $title
	 */
	function OpenTableTitle($title)
	{
		echo "$title<br />";
	}
}
if (  !function_exists("CloseTableTitle") )
{
	/**
	 * close table with title
	 *
	 */
	function CloseTableTitle()
	{
		echo "<br />";
	}
}
if (  !function_exists("OpenTable") )
{
	/**
	 * Open table
	 *
	 */
	function OpenTable()
	{
		echo "<table><tr><td>";
	}
}
if (  !function_exists("CloseTable") )
{
	/**
	 * Close table
	 *
	 */
	function CloseTable()
	{
		echo "</td></tr></table>";
	}
}
if (  !function_exists("FN_OpenFootNews") )
{
	/**
	 * Open news footer
	 *
	 */
	function FN_OpenFootNews()
	{
		echo "
		<table width=\"100%\" style=\"text-align:center\" >
			<tr>
				<td align=\"center\" >
		";
	}
}
if (  !function_exists("FN_CloseFootNews") )
{
	/**
	 * Close news footer
	 *
	 */
	function FN_CloseFootNews()
	{
		echo "
				</td>
			</tr>
		</table>";
	}
}
if (  !function_exists("get_footer_array") )
{
	/**
	 * get footer values
	 *
	 * @return array
	 */
	function get_footer_array()
	{
		global $_FN;
		global $admin_mail,$admin;
		$ret_strings['img_fn'] = "<a href=\"http://flatnux.sf.org/\" onclick=\"window.open(this.href);return false;\" title=\"FlatNux\">";
		$ret_strings['img_fn'] .= "<img align=\"middle\" border=\"0\" src=\"" . fromtheme("images/validate/flatnuke_powered.png") . "\" alt=\"FlatNux\" /></a>";
		$ret_strings['img_w3c'] = "<a href=\"http://validator.w3.org/check/referer\" onclick=\"window.open(this.href);return false;\" title=\"Valid HTML 4.01!\">";
		$ret_strings['img_w3c'] .= "<img align=\"middle\" border=\"0\" src=\"" . fromtheme("images/validate/valid_html401.png") . "\" alt=\"Valid HTML 4.01!\" /></a>";
		$ret_strings['img_css'] = "<a href=\"http://jigsaw.w3.org/css-validator/check/referer\" onclick=\"window.open(this.href);return false;\" title=\"Valid CSS!\">";
		$ret_strings['img_css'] .= "<img align=\"middle\" border=\"0\" src=\"" . fromtheme("images/validate/valid_css.png") . "\" alt=\"Valid CSS!\" /></a>";
		$ret_strings['img_rss'] = "<a href=\"{$_FN['datadir']}/{$_FN['lang']}/backend.xml\" onclick=\"window.open(this.href);return false;\" title=\"Get RSS 2.0 Feed\">";
		$ret_strings['img_rss'] .= "<img align=\"middle\" border=\"0\" src=\"" . fromtheme("images/validate/rss20_powered.png") . "\" alt=\"Get RSS 2.0 Feed\" /></a>";
		$ret_strings['img_mail'] = "<a href=\"mailto:" . email_mask($admin_mail) . "\" title=\"Site admin: " . $admin . "\">";
		$ret_strings['img_mail'] .= "<img align=\"middle\" border=\"0\" src=\"" . fromtheme("images/validate/email.png") . "\" alt=\"Mail me!\" /></a>";
		$ret_strings['legal'] = _LEGAL;
		$time2 = get_microtime();
		$ret_strings['time'] = "Page generated in " . sprintf("%.4f",abs($time2 - $_FN['timestart'])) . " seconds.";
		return $ret_strings;
	}
}
if (  !function_exists("xmldb_get_lang_img") )
{
	/**
	 * get language image used in xmldb forms
	 *
	 * @param string lang
	 * @return string
	 */
	function xmldb_get_lang_img($lang)
	{
		return "<img alt=\"$lang\" border=\"0\" src=\"" . fromtheme("images/flags/$lang.png") . "\" />";
	}
}
if (  !function_exists("theme_doctype") )
{
	/**
	 * 
	 * @return string
	 */
	function theme_doctype()
	{
		return "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.01 Transitional//EN\">\n"; // default HTML 4.01 doctype
	}
}
if (  !function_exists("tooltip") )
{
	/**
	 *
	 * @param string $text
	 * @return string
	 */
	function tooltip($text)
	{
		if ( $text != "" && $text != null )
		{
			$text = html_entity_decode($text,ENT_QUOTES);
			$text = str_replace("'","\\'",$text);
			$text = str_replace('"',"\\'",$text);
			$text = str_replace("\n",'<br />',$text);
			$text = str_replace("\r",'',$text);
			$ret = " onmouseover = \"this.title='$text' \" ";
		}
		return $ret;
	}
}
if (  !function_exists("fn_print_menu") )
{
	/**
	 *
	 * @global array $_FN
	 * @staticvar int $slevel
	 * @param string $path
	 * @param string $menu_recursive
	 * @param string $show_icons
	 * @param string $menu_recursive_onlyselected
	 * @return string
	 */
	function fn_print_menu($path, $menu_recursive, $show_icons, $menu_recursive_onlyselected, $sep)
	{
		global $_FN;
		static $slevel = 0;
		$html = "";
		$modlist = list_sections_translated($path,false,false);
		$slevel++ ;
		$tl = ($_FN['lang'] != $_FN['lang_default']) ? "&lang={$_FN['lang']}" : "";
		$c = 0;
		foreach ( $modlist as $mod )
		{
			$tmp = $mod['title'];
			$link = $mod['link'];
			$accesskey = $mod['accesskey'];
			if ( $_FN['home_section'] == "" )
				$html .= "&nbsp;&nbsp;";
			for ( $i = 1;$i < $slevel;$i++  )
			{
				if ( $sep == "<br />" )
					$html .= "&nbsp;&nbsp;&nbsp;&nbsp;";
			}
			if ( $slevel == 1 )
			{
				//$html.= "<b>";
			}
			$icon = "";
			if ( $show_icons && file_exists("themes/{$_FN['theme']}/images/menu.png") )
			{
				if ( file_exists("sections/$link/icon.png") )
					$icon = "<img src=\"sections/$link/icon.png\" alt=\"\"/>&nbsp;";
				else
					$icon = "<img src=\"" . fromtheme("images/section.png") . "\" alt=\"\"/>&nbsp;";
			}
			$hlink = get_section_id($link);
			$c++ ;
			$html .= "\n\t$icon<a accesskey=\"$accesskey\" href=\"" . fn_rewritelink("index.php?mod=$hlink$tl") . "\">$tmp</a>";
			if ( $slevel == 1 )
			{
				//$html.= "</b>";
			}
			$l = basename($link);
			$html .= "$sep";
			if ( $menu_recursive )
			{
				if ( $menu_recursive_onlyselected && fn_erg('^' . $mod['link'],$_FN['vmod']) )
					$html .= fn_print_menu("$path/$l",$menu_recursive,$show_icons,$menu_recursive_onlyselected);
				else
				{
					if (  !$menu_recursive_onlyselected )
						$html .= fn_print_menu("$path/$l",$menu_recursive,$show_icons,$menu_recursive_onlyselected,$sep);
				}
			}
		}
		$slevel-- ;
		return $html;
	}
}
?>