<?php
/**
 * @author Alessandro Vernassa <speleoalex@gmail.com>
 * @copyright Copyright (c) 2003-2009
 * @license http://opensource.org/licenses/gpl-license.php GNU General Public License
 * @package xmldb
 *
 */
/**
 *
 * @param string $databasename
 * @param string $tablename
 * @param string $path
 * @param array $params
 * @return object XMLTable
 */
function xmldb_form($databasename,$tablename,$path = "misc",$lang = "en",$languages = "en,it",$params = false)
{
	static $tables=false;
	if (!is_array($tablename))
	{
		$id="$databasename,$tablename,$path,$lang,$languages";
		if (!isset($tables[$id]))
		{
			$tables[$id]=new FieldForm($databasename,$tablename,$path,$lang,$languages,$params);
		}
		return $tables[$id];
	}
	else
		return new FieldForm($databasename,$tablename,$path,$lang,$languages,$params);
}
/**
 *
 * LoadFieldsForm
 *
 * Carica i fields pronti per essere utilizzati dai forms con i titoli gi tradotti.
 * Come devono essere gestiti i campi per il form  descritto nella tabella stessa.
 *
 *
 *
 * PROPRIETA' RELATIVE A I FORM:
 * frm_setonlyadmin : visualizza solo l'amministratore
 *
 *
 * foreignkey        : tabella lincata
 * fk_link_field     : campo da lincare alla tabella (deve essere univoco, conviene sempre usare la chiave primaria)
 * fk_show_field     : campo da visualizzare
 * title             : titolo
 * title_xx          : titolo tradotto
 * frm_type          : tipo di dato, file,image,text,string,check,html,password,separator(mostra solo il nome del campo)
 * frm_help          : tooltip
 * frm_help_xx       : tooltip tradotto nella lingua xx
 * frm_checkon       : valore se il check  settato
 * frm_multilanguage : abita l' inserimento di un dato in pi lingue
 * frm_required      : il dato deve essere inserito
 * frm_setonlyadmin  : solo l' amministratore pu inserire il dato
 * frm_allowupdate   : il campo non pu essere mai aggiornato
 * frm_assoc         : il cmpo viene visualizzato solo se ne  presente un altro
 * frm_show          : il campo viene visualizzato
 * frm_retype        : chiede il campo due volte
 * frm_rows          : dimensioni, altezza
 * frm_cols          : dimensioni, colonne
 * frm_size          : dimensioni
 * frm_allowhtml     : permette l'inserimento di codice html
 * frm_maximagesize  : dimensione masima file
 * frm_required_condition : condizione per cui il campo e' obbligatorio es
 *
 */
class FieldForm
{
	function FieldForm($databasename,$tablename,$path = "misc",$lang = "en",$languages = "en,it",$params = false)
	{
		$this->databasename=$databasename;
		if (is_array($tablename))
		{
			if (empty($tablename['tablename']))
				$tablename['tablename']="____empty_____";
			$this->tablename=$tablename['tablename'];
		}
		else
		{
			$this->tablename=$tablename;
		}
		$this->table=$tablename;

		$this->path=$path;
		$this->lang=$lang;
		$this->languages=$languages;
		$this->tableparams=$params;
		$this->formvals=$this->LoadFieldsForm();
		$this->LoadFieldsClasses();
		$this->initmessages();
		$this->requiredtext="*";
		//dprint_r($this->xmltable->fields[$this->xmltable->primarykey]->extra);
		if (!(isset($this->xmltable->fields[$this->xmltable->primarykey]->extra) && $this->xmltable->fields[$this->xmltable->primarykey]->extra == 'autoincrement'))
		{
			$this->formvals[$this->xmltable->primarykey]['frm_required']=1;
		}
		$this->setlayout("default");
	}
	function LoadFieldsClasses()
	{
		foreach ($this->formvals as $field)
		{
			if (!isset($field['frm_type']) || $field['frm_type'] == "varchar")
				if ((isset($field['foreignkey']) && $field['foreignkey'] != ""))
				{
					$field['frm_type']="select";
				}
			if (class_exists('xmldbform_field_' . $field['frm_type']))
				$classname='xmldbform_field_' . $field['frm_type'];
			else
			{
				if (isset($field['type']) && $field['type'] == "text")
					$classname='xmldbform_field_text';
				elseif (isset($field['type']) && $field['type'] == "file")
					$classname='xmldbform_field_file';
				else
					$classname='xmldbform_field_varchar';
			}
			$param['fieldvalues']=$field;
			$this->formclass[$field['name']]=new $classname($param);
		}
	}
	/**
	 * set languages
	 */
	function InitMessages()
	{
		switch ($this->lang)
		{
			case "it" :
				$this->messages["_XMLDBREQUIRED"]="il campo non pu&ograve; essere vuoto";
				$this->messages["_XMLDBNOTVALIDFIED"]="il valore inserito non &egrave; corretto";
				$this->messages["_XMLDBNOTVALIDIMAGE"]="il valore inserito non &egrave; un immagine valida";
				$this->messages["_XMLDBTOOBIG"]="l'immagine deve essere meno di ";
				$this->messages["_XMLDBEXISTS"]="esiste gi&agrave;";
				$this->messages["_XMLDBERRORRETYPE"]="i valori non corrispondono";
				$this->messages["_XMLDBRETYPE"]="ridigita";
				$this->messages["_XMLDBDELETE"]="elimina";
				break;
			case "en" :
			default :
				$this->messages["_XMLDBREQUIRED"]="the value is empty";
				$this->messages["_XMLDBNOTVALIDFIED"]="the value is not valid";
				$this->messages["_XMLDBNOTVALIDIMAGE"]="the value is not valid image";
				$this->messages["_XMLDBTOOBIG"]="the image must be smaller than 100";
				$this->messages["_XMLDBEXISTS"]="this value alredy exists";
				$this->messages["_XMLDBERRORRETYPE"]="the values are not equal";
				$this->messages["_XMLDBRETYPE"]="retype";
				$this->messages["_XMLDBDELETE"]="delete";
				break;
		}
	}
	/**
	 * setlayoutTags
	 * set all propriety
	 *
	 * @param string $frm_starttagtitle
	 * @param string $frm_endtagtitle
	 * @param string $frm_starttagvalue
	 * @param string $frm_endtagvalue
	 * @param string $frm_startgroupheader
	 * @param string $frm_endgroupheader
	 * @param string $frm_startgroupfooter
	 * @param string $frm_endgroupfooter
	 */
	function SetlayoutTags($frm_starttagtitle,$frm_endtagtitle,$frm_starttagvalue,$frm_endtagvalue,$frm_startgroupheader = "",$frm_endgroupheader = "",$frm_startgroupfooter = "",$frm_endgroupfooter = "")
	{
		foreach ($this->formvals as $key=>$value)
		{
			$this->formvals[$key]['frm_starttagtitle']=$frm_starttagtitle;
			$this->formvals[$key]['frm_endtagtitle']=$frm_endtagtitle;
			$this->formvals[$key]['frm_starttagvalue']=$frm_starttagvalue;
			$this->formvals[$key]['frm_endtagvalue']=$frm_endtagvalue;
			$this->formvals[$key]['frm_startgroupheader']=$frm_startgroupheader;
			$this->formvals[$key]['frm_endgroupheader']=$frm_endgroupheader;
			$this->formvals[$key]['frm_startgroupfooter']=$frm_startgroupfooter;
			$this->formvals[$key]['frm_endgroupfooter']=$frm_endgroupfooter;
		}
	}
	/**
	 * setlayoutTag
	 * set field propriety
	 *
	 * @param string $tagname
	 * @param string $frm_starttagtitle
	 * @param string $frm_endtagtitle
	 * @param string $frm_starttagvalue
	 * @param string $frm_endtagvalue
	 * @param string $frm_startgroupheader
	 * @param string $frm_endgroupheader
	 * @param string $frm_startgroupfooter
	 * @param string $frm_endgroupfooter 
	 */
	function SetlayoutTag($tagname,$frm_starttagtitle,$frm_endtagtitle,$frm_starttagvalue,$frm_endtagvalue,$frm_startgroupheader = "",$frm_endgroupheader = "",$frm_startgroupfooter = "",$frm_endgroupfooter = "")
	{
		$this->formvals[$tagname]['frm_starttagtitle']=$frm_starttagtitle;
		$this->formvals[$tagname]['frm_endtagtitle']=$frm_endtagtitle;
		$this->formvals[$tagname]['frm_starttagvalue']=$frm_starttagvalue;
		$this->formvals[$tagname]['frm_endtagvalue']=$frm_endtagvalue;
		$this->formvals[$tagname]['frm_startgroupheader']=$frm_startgroupheader;
		$this->formvals[$tagname]['frm_endgroupheader']=$frm_endgroupheader;
		$this->formvals[$tagname]['frm_startgroupfooter']=$frm_startgroupfooter;
		$this->formvals[$tagname]['frm_endgroupfooter']=$frm_endgroupfooter;
	}
	/**
	 * setlayout
	 * set all propriety
	 *
	 */
	function SetLayout($mode = "table")
	{
		switch ($mode)
		{
			case "table" :
				$this->setlayoutTags("<tr><td>","</td>","<td>","</td></tr>","<tr><td colspan=\"2\"><b>","</b></td></tr>","","");
				break;
			case "default" :
				$this->setlayoutTags("<b>","</b>","","<br /><br />","<fieldset><legend>","</legend>","","</fieldset>");
				break;
			default :
				$this->setlayoutTags("<b>","</b>","","<br /><br />","<fieldset><legend>","</legend>","","</fieldset>");
				break;
		}
	}
	/**
	 *
	 * @staticvar boolean $options
	 * @param <type> $values
	 * @return <type>
	 */
	function LoadFieldsForm($values = "")
	{
		static $options=false;
		$databasename=$this->databasename;
		$tablename=$this->tablename;
		$lang=$this->lang;
		$path=$this->path;
		$this->xmltable=xmldb_table($databasename,$this->table,$path,$this->tableparams);
		$table=$this->xmltable;
		$records=$table->fields;
		if (isset($this->xmltable->xmldescriptor))
			$this->innertables=xmldb_xml2array($this->xmltable->xmldescriptor,"innertable",false);
		else
			$this->innertables=false;
		$ret=array();
		foreach ($records as $record)
		{
			$record=get_object_vars($record);
			$tmp=array();
			foreach ($record as $k=>$v)
				$tmp[$k]=$v;
			// add missing fields
			if (!empty($record['frm_multilanguages']))
			{
				if ($record['frm_multilanguages'] == "auto")
				{
					$record['frm_multilanguages']=$this->languages;
					$tmp['frm_multilanguages']=$this->languages;
				}
				$languages=explode(",",$record['frm_multilanguages']);
				$f=false;
				foreach ($languages as $l)
				{
					// first field is default field
					if (!$f)
					{
						if (isset($records[$record['name'] . "_$l"]))
						{
							unset($records[$record['name'] . "_$l"]);
						}
						$f=true;
						continue;
					}
					$tfield['name']=$record['name'] . "_$l";
					$tfield['type']=$record['type'];
					$tfield['frm_multilanguage']="1";
					if (!isset($records[$record['name'] . "_$l"]))
					{
						addxmltablefield($this->databasename,$this->table,$tfield,$this->path);
					}
				}
			}
			/*			 * ******************************************************** */
			if (!isset($options[$tmp['name']]))
			{
				$options[$tmp['name']]=$this->LoadOptions($record,$values);
			}
			$tmp['options']=&$options[$tmp['name']];
			if (!isset($tmp['frm_type']))
				$tmp['frm_type']=isset($tmp['type']) ? $tmp['type'] : "text";
			$tmp['title']=$record['name'];
			if (!empty($record['frm_group_' . $lang]))
				$tmp['frm_group']=$record['frm_group_' . $lang];
			if (!empty($record['frm_endgroup_' . $lang]))
				$tmp['frm_endgroup']=$record['frm_endgroup_' . $lang];
			//--set field title--->
			if (!empty($record['frm_' . $lang]))
				$tmp['title']=$record['frm_' . $lang];
			elseif (!empty($record['frm_en']))
				$tmp['title']=$record['frm_en'];
			//--set field title----<
			if (!empty($record['frm_help_' . $lang]))
				$tmp['frm_help']=$record['frm_help_' . $lang];
			$tmp['frm_checkon']=isset($record['frm_checkon']) ? $record['frm_checkon'] : 1;
			$ret[$record['name']]=$tmp;
		}
		return $ret;
	}
	/**
	 *
	 * @param object $record
	 * @param array $values
	 * @return array
	 */
	function LoadOptions($record,$values = "")
	{
		$databasename=$this->databasename;
		$path=$this->path;
		$lang=$this->lang;
		$tmp['options']=false;
		if (isset($record['foreignkey']) && $record['foreignkey'] !== "" && isset($record['fk_link_field']) && isset($record['fk_show_field']))
		{
			$databasename_fk=$databasename;
			$path_fk=$path;
			if (isset($record['fk_databasepath']) && $record['fk_databasepath'] != "")
			{
				$path_fk=$record['fk_databasepath'];
			}
			if (isset($record['fk_databasename']) && $record['fk_databasename'] != "")
			{
				$databasename_fk=$record['fk_databasename'];
			}
			$listaopzionitabella=xmldb_table($databasename_fk,$record['foreignkey'],$path_fk);
			if (!isset($listaopzionitabella->driver))
			{
				$listaopzioni=array();
			}
			else
			{
				$restr=false;
				//esempio clausula su foreignkey
				// $Table->formvals['periodo']['fk_filter_field']="id_procurement='1',Abilitato='True'";
				if (isset($record['fk_filter_field']) && $record['fk_filter_field'] != "")
				{
					//if exist a clause
					$clausule=explode("=",$record['fk_filter_field']);
					if (isset($clausule[1]))
					{
						//all clauses separated by commas
						$clausules=explode(",",$record['fk_filter_field']);
						$restr=array();
						foreach ($clausules as $clk=>$claus_item)
						{
							$clausule=explode("=",$claus_item);
							$cname1=trim(ltrim($clausule[0]));
							$cname2=trim(ltrim($clausule[1]));
							//left of equal is the name of field
							if (isset($listaopzionitabella->fields[$cname1]))
							{
								if (isset($values[$cname2]))
									$restr[$cname1]=$values[$cname2];
								else
								{
									// if is  key='pippo'
									if ($cname2[0] == "'" && $cname2[strlen($cname2) - 1] == "'")
										$restr[$cname1]=substr($cname2,1,strlen($cname2) - 2);
									else
										$restr[$cname1]=$cname2;
								}
							}
						}
						$listaopzioni=$listaopzionitabella->GetRecords($restr);
					}
					else
					{
						$listaopzioni=array();
					}
				}
				else
				{
					$listaopzioni=$listaopzionitabella->GetRecords();
				}
			}
			$retopzioni=array();
			$tmp2=array();
			if (is_array($listaopzioni))
				foreach ($listaopzioni as $opzione)
				{
					$tmp2['value']=$opzione[$record['fk_link_field']];
					$showfields=explode(",",$record['fk_show_field']);
					$tmp2['title']="";
					$sep="";
					foreach ($showfields as $showfield)
					{
						$tmp2['title'] .= $sep;
						if (isset($opzione[$showfield . "_$lang"]) && $opzione[$showfield . "_$lang"] != "")
							$tmp2['title'] .= $opzione[$showfield . "_$lang"];
						else
							$tmp2['title'] .= isset($opzione[$showfield]) ? $opzione[$showfield] : "";
						$sep=" ";
					}
					if (isset($record['frm_show_image']) && isset($opzione[$record['frm_show_image']]))
					{
						$tmp2['frm_show_image']=$path_fk . "/" . $databasename_fk . "/" . $record['foreignkey'] . "/" . $opzione[$listaopzionitabella->primarykey] . "/" . $record['frm_show_image'] . "/thumbs/" . $opzione[$record['frm_show_image']] . ".jpg";
						$tmp2['thumbsize']=isset($listaopzionitabella->fields[$record['frm_show_image']]->thumbsize) ? $listaopzionitabella->fields[$record['frm_show_image']]->thumbsize : 16; //dprint_r($tmp2);
					}
					$retopzioni[]=$tmp2;
				}
			$tmp['options']=$retopzioni;
		}
		else
		{
			//-------options written statically in the descriptor  ----->
			if (isset($record['frm_options']) && $record['frm_options'] !== "")
			{
				$retopzioni=array();
				$listaopzioni=explode(",",$record['frm_options']);
				$iopz=0;
				foreach ($listaopzioni as $opzione)
				{
					$retopzioni[$iopz]['title']=$opzione;
					$retopzioni[$iopz]['value']=$opzione;
					$iopz++;
				}
				if (isset($record['frm_options_' . $this->lang]) && $record['frm_options_' . $this->lang] !== "")
				{
					$iopz=0;
					$listaopzioni=explode(",",$record['frm_options_' . $this->lang]);
					foreach ($listaopzioni as $opzione)
					{
						$retopzioni[$iopz]['title']=$opzione;
						$iopz++;
					}
				}
				$tmp['options']=$retopzioni;
				//-------options written statically in the descriptor  -----<
			}
		}
		return $tmp['options'];
	}
	/**
	 * ShowUpdateForm
	 * show update form
	 *
	 * @param string $pk
	 * @param bool $isadmin
	 * @param array values
	 *
	 */
	function ShowUpdateForm($pk,$isadmin = false,$nvalues = false)
	{
		$values=xmldb_table($this->databasename,$this->table,$this->path,$this->tableparams);
		$values=$values->GetRecordByPrimaryKey($pk);
		if ($nvalues != false)
			foreach ($nvalues as $k=>$v)
				$values[$k]=$v;
		$this->ShowForm(true,$values,$isadmin,$values);
	}
	/**
	 * ShowInsertForm
	 * show form insert
	 *
	 * @param string $isadmin
	 * @param string $values
	 */
	function ShowInsertForm($isadmin = false,$values = false)
	{
		$this->ShowForm(false,$values,$isadmin);
	}
	/**
	 * ShowForm
	 * show the form
	 * @param bool $update
	 * @param array $oldvalues
	 * @param bool $isadmin
	 */
	function ShowForm($update = false,$oldvalues = false,$isadmin = false)
	{
		$lang=$this->lang;
		foreach ($this->formvals as $k=>$fv)
		{
			if (isset($fv['primarykey']) && $fv['primarykey'] == "1")
				$primarykey=$k;
		}
		//if primarykey is missing I force viewing
		$strhiddenfield="";
		if ($update == true)
			$strhiddenfield="<input readonly=\"readonly\" type=\"hidden\" name=\"_xmldbform_pk_$primarykey\" value=\"" . $oldvalues[$primarykey] . "\" />";
		if ($update == true && isset($this->formvals[$primarykey]['frm_show']) && ($this->formvals[$primarykey]['frm_show'] === "0" || $this->formvals[$primarykey]['frm_show'] === 0))
		{
			$strhiddenfield .= "<input type=\"hidden\" name=\"$primarykey\" value=\"" . $oldvalues[$primarykey] . "\" />";
		}
		if ($update == true && isset($this->formvals[$primarykey]['frm_allowupdate']) && $this->formvals[$primarykey]['frm_allowupdate'] == 0)
		{
			$strhiddenfield .= "<input type=\"hidden\" name=\"$primarykey\" value=\"" . $oldvalues[$primarykey] . "\" />";
		}
		if ($update == true && isset($this->formvals[$primarykey]['frm_setonlyadmin']) && $this->formvals[$primarykey]['frm_setonlyadmin'] == 1 && !is_admin())
		{
			$strhiddenfield .= "<input type=\"hidden\" name=\"$primarykey\" value=\"" . $oldvalues[$primarykey] . "\" />";
		}
		$extravalues=null;
		foreach ($this->formvals as $extravaluesk=>$extravalues)
		{
			if (isset($extravalues['fk_filter_field']) && $extravalues['fk_filter_field'] != "")
				$extravalues['options']=$this->LoadOptions($extravalues,$oldvalues);
			if (isset($extravalues['frm_group']) && $extravalues['frm_group'] != "")
			{
				$gtitle=$extravalues['frm_group'];
				echo $this->formvals[$extravaluesk]['frm_startgroupheader'] . $gtitle . $this->formvals[$extravaluesk]['frm_endgroupheader'];
			}
			// --------multilanguage -------------->
			if (isset($extravalues['frm_multilanguage']) && $extravalues['frm_multilanguage'] == 1)
			{
				continue;
			}
			$extravalues['realname']=$extravalues['name'];
			$lang_user=$lang;
			$multilanguage=false;
			$oldval=isset($oldvalues[$extravaluesk]) ? $oldvalues[$extravaluesk] : "";
			$lang_noprefix="";
			$languagesfield="";
			if (isset($extravalues['frm_multilanguages']) && $extravalues['frm_multilanguages'] != "")
			{
				$multilanguage=true;
				$languagesfield=explode(",",$extravalues['frm_multilanguages']);
				$lang_noprefix=$languagesfield[0];
				if (!in_array($lang_user,$languagesfield))
					$lang_user=$lang_noprefix;
				if (isset($this->formvals[$extravalues['name'] . "_$lang_user"]))
				{
					if ($lang_noprefix != $lang_user)
					{
						$extravalues['name']=$extravalues['name'] . "_$lang_user";
						if (isset($oldvalues[$extravaluesk . "_$lang_user"]))
							$oldval=$oldvalues[$extravaluesk . "_$lang_user"];
						else
							$oldval="";
					}
				}
			}
			// --------multilanguage --------------<
			if (isset($extravalues['frm_required']) && $extravalues['frm_required'] == 1)
				$extravalues['title'] .= " " . $this->requiredtext;
			//------------gestione visualizzazione----------->
			$showfield=true;
			if (isset($extravalues['frm_setonlyadmin']) && $extravalues['frm_setonlyadmin'] == 1 && $isadmin != true)
				$showfield=false;
			if ($update == true && isset($extravalues['frm_allowupdate']))
			{
				if ($extravalues['frm_allowupdate'] === "0" || $extravalues['frm_allowupdate'] == "onlyadmin")
				{
					$showfield=false;
				}
				if ($extravalues['frm_allowupdate'] == "onlyadmin" && $isadmin == true)
				{
					$showfield=true;
				}
			}
			if (isset($extravalues['frm_assoc']) && $extravalues['frm_assoc'] != "")
			{
				if (!isset($oldvalues[$extravalues['frm_assoc']]) || $oldvalues[$extravalues['frm_assoc']] == "")
				{
					$showfield=false;
				}
			}
			if (isset($extravalues['frm_show']) && ($extravalues['frm_show'] === "0" || $extravalues['frm_show'] === 0))
				$showfield=false;
			//if exist custom function
			if (isset($extravalues['frm_functionform']) && $extravalues['frm_functionform'] != "" && function_exists($extravalues['frm_functionform']))
			{
				eval($extravalues['frm_functionform'] . '($oldvalues,$extravaluesk);');
				$showfield=false;
			}
			//------------gestione visualizzazione-----------<
			$extravalues['messages']=$this->messages;
			//valore di default
			if (isset($extravalues['frm_default']) && $update == false)
			{
				$oldval=$extravalues['frm_default'];
			}
			$extravalues['value']=$oldval;
			$extravalues['strhiddenfield']=$strhiddenfield;
			$extravalues['fieldform']=$this;
			$extravalues['oldvalues']=$oldvalues;
			$extravalues['oldvalues_primarikey']=$primarykey;
			$extravalues['multilanguage']=$multilanguage;
			$extravalues['lang_user']=$lang_user;
			$extravalues['lang']=$lang;
			$extravalues['lang_noprefix']=$lang_noprefix;
			$extravalues['languagesfield']=$languagesfield;
			$extravalues['frm_help']=isset($extravalues['frm_help']) ? $extravalues['frm_help'] : "";
			if ($showfield)
			{
				$this->formclass[$extravaluesk]->show($extravalues);
				//scrive la chiave primaria una sola volta
				$strhiddenfield="";
			}
			if (isset($extravalues['frm_endgroup']))
			{
				echo $this->formvals[$extravaluesk]['frm_startgroupfooter'] . $extravalues['frm_endgroup'] . $this->formvals[$extravaluesk]['frm_endgroupfooter'];
			}
		}
		$params=false;
	}
	/**
	 * ShowForm
	 * show the form
	 * @param bool $update
	 * @param array $oldvalues
	 * @param bool $isadmin
	 */
	function ShowSearchForm($oldvalues = false,$isadmin = false)
	{
		$lang=$this->lang;
		foreach ($this->formvals as $k=>$fv)
		{
			if (isset($fv['primarykey']) && $fv['primarykey'] == "1")
				$primarykey=$k;
		}
		//if primarykey is missing I force viewing
		$strhiddenfield="";
		$update=true;
		/*
		  if ($update == true)
		  $strhiddenfield="<input readonly=\"readonly\" type=\"hidden\" name=\"_xmldbform_pk_$primarykey\" value=\"" . $oldvalues[$primarykey] . "\" />";
		  if ($update == true && isset($this->formvals[$primarykey]['frm_search']) && ($this->formvals[$primarykey]['frm_search'] === "0" || $this->formvals[$primarykey]['frm_search'] === 0))
		  {
		  $strhiddenfield .= "<input type=\"hidden\" name=\"$primarykey\" value=\"" . $oldvalues[$primarykey] . "\" />";
		  }
		  if ($update == true && isset($this->formvals[$primarykey]['frm_allowupdate']) && $this->formvals[$primarykey]['frm_allowupdate'] == 0)
		  {
		  $strhiddenfield .= "<input type=\"hidden\" name=\"$primarykey\" value=\"" . $oldvalues[$primarykey] . "\" />";
		  }
		  if ($update == true && isset($this->formvals[$primarykey]['frm_setonlyadmin']) && $this->formvals[$primarykey]['frm_setonlyadmin'] == 1 && !is_admin())
		  {
		  $strhiddenfield .= "<input type=\"hidden\" name=\"$primarykey\" value=\"" . $oldvalues[$primarykey] . "\" />";
		  }
		 */
		$extravalues=null;
		foreach ($this->formvals as $extravaluesk=>$extravalues)
		{


			if (isset($extravalues['fk_filter_field']) && $extravalues['fk_filter_field'] != "")
				$extravalues['options']=$this->LoadOptions($extravalues,$oldvalues);
			if (isset($extravalues['frm_group']) && $extravalues['frm_group'] != "")
			{
				$gtitle=$extravalues['frm_group'];
				echo $this->formvals[$extravaluesk]['frm_startgroupheader'] . $gtitle . $this->formvals[$extravaluesk]['frm_endgroupheader'];
			}
			// --------multilanguage -------------->
			if (isset($extravalues['frm_multilanguage']) && $extravalues['frm_multilanguage'] == 1)
			{
				continue;
			}
			$extravalues['realname']=$extravalues['name'];
			$lang_user=$lang;
			$multilanguage=false;
			$oldval=isset($oldvalues[$extravaluesk]) ? $oldvalues[$extravaluesk] : "";
			$lang_noprefix="";
			$languagesfield="";
			if (isset($extravalues['frm_multilanguages']) && $extravalues['frm_multilanguages'] != "")
			{
				$multilanguage=true;
				$languagesfield=explode(",",$extravalues['frm_multilanguages']);
				$lang_noprefix=$languagesfield[0];
				if (!in_array($lang_user,$languagesfield))
					$lang_user=$lang_noprefix;
				if (isset($this->formvals[$extravalues['name'] . "_$lang_user"]))
				{
					if ($lang_noprefix != $lang_user)
					{
						$extravalues['name']=$extravalues['name'] . "_$lang_user";
						if (isset($oldvalues[$extravaluesk . "_$lang_user"]))
							$oldval=$oldvalues[$extravaluesk . "_$lang_user"];
						else
							$oldval="";
					}
				}
			}
			// --------multilanguage --------------<
			if (isset($extravalues['frm_required']) && $extravalues['frm_required'] == 1)
				$extravalues['title'] .= " " . $this->requiredtext;
			//------------gestione visualizzazione----------->
			$showfield=true;
			if (isset($extravalues['frm_setonlyadmin']) && $extravalues['frm_setonlyadmin'] == 1 && $isadmin != true)
				$showfield=false;
			if ($update == true && isset($extravalues['frm_allowupdate']))
			{
				if ($extravalues['frm_allowupdate'] === "0" || $extravalues['frm_allowupdate'] == "onlyadmin")
				{
					$showfield=false;
				}
				if ($extravalues['frm_allowupdate'] == "onlyadmin" && $isadmin == true)
				{
					$showfield=true;
				}
			}
			if (isset($extravalues['frm_assoc']) && $extravalues['frm_assoc'] != "")
			{
				if (!isset($oldvalues[$extravalues['frm_assoc']]) || $oldvalues[$extravalues['frm_assoc']] == "")
				{
					$showfield=false;
				}
			}
			if (empty($extravalues['frm_search']))
				$showfield=false;
			//if exist custom function
			if (isset($extravalues['frm_functionform']) && $extravalues['frm_functionform'] != "" && function_exists($extravalues['frm_functionform']))
			{
				eval($extravalues['frm_functionform'] . '($oldvalues,$extravaluesk);');
				$showfield=false;
			}
			//------------gestione visualizzazione-----------<
			$extravalues['messages']=$this->messages;
			//valore di default
			if (isset($extravalues['frm_default']) && $update == false)
			{
				$oldval=$extravalues['frm_default'];
			}
			$extravalues['value']=$oldval;
			$extravalues['strhiddenfield']=$strhiddenfield;
			$extravalues['fieldform']=$this;
			$extravalues['oldvalues']=$oldvalues;
			$extravalues['oldvalues_primarikey']=$primarykey;
			$extravalues['multilanguage']=$multilanguage;
			$extravalues['lang_user']=$lang_user;
			$extravalues['lang']=$lang;
			$extravalues['lang_noprefix']=$lang_noprefix;
			$extravalues['languagesfield']=$languagesfield;
			$extravalues['frm_help']=isset($extravalues['frm_help']) ? $extravalues['frm_help'] : "";
			if ($showfield)
			{
				$str="";
				$str .= "<select name=\"_search_{$extravalues['name']}\" >";
				$str .= "<option  value=\"\" >ignora campo</option>";
				$s=(isset($oldvalues["_search_{$extravalues['name']}"]) && $oldvalues["_search_{$extravalues['name']}"] == "_x_") ? "selected=\"selected\"" : "";
				$str .= "<option $s value=\"_x_\" >contiene</option>";
				$s=(isset($oldvalues["_search_{$extravalues['name']}"]) && $oldvalues["_search_{$extravalues['name']}"] == "x") ? "selected=\"selected\"" : "";
				$str .= "<option $s value=\"x\">uguale</option>";
				$s=(isset($oldvalues["_search_{$extravalues['name']}"]) && $oldvalues["_search_{$extravalues['name']}"] == "x_") ? "selected=\"selected\"" : "";
				$str .= "<option  $s value=\"x_\" >inizia per</option>";
				$s=(isset($oldvalues["_search_{$extravalues['name']}"]) && $oldvalues["_search_{$extravalues['name']}"] == "_x") ? "selected=\"selected\"" : "";
				$str .= "<option  $s value=\"_x\">finisce per</option>";
				$s=(isset($oldvalues["_search_{$extravalues['name']}"]) && $oldvalues["_search_{$extravalues['name']}"] == "<") ? "selected=\"selected\"" : "";
				$str .= "<option  $s value=\"<\">&egrave minore di</option>";
				$s=(isset($oldvalues["_search_{$extravalues['name']}"]) && $oldvalues["_search_{$extravalues['name']}"] == ">") ? "selected=\"selected\"" : "";
				$str .= "<option  $s value=\">\">&egrave maggiore di</option>";
				if (!empty($extravalues['frm_search_ranges']))
				{
					$s=(isset($oldvalues["_search_{$extravalues['name']}"]) && $oldvalues["_search_{$extravalues['name']}"] == "range") ? "selected=\"selected\"" : "";
					$str .= "<option $s value=\"range\">&egrave compreso tra</option>";
				}$str .= "</select>";
				$extravalues['frm_starttagvalue'] .= $str;
				if (!empty($extravalues['frm_search_ranges']))
				{
					$extravalues2=$extravalues;
					$extravalues2['strhiddenfield']="";
					$extravalues2['frm_starttagvalue']="";
					$extravalues2['frm_endtagvalue']="";
					$extravalues2['frm_starttagtitle']="";
					$extravalues2['frm_endtagtitle']="";
					$extravalues2['title']="";
					$extravalues2['value']=(!empty($oldvalues["_search_range_end_" . $extravalues2['name']])) ? $oldvalues["_search_range_end_" . $extravalues2['name']] : "";
					$extravalues2['name']="_search_range_end_" . $extravalues2['name'];
					ob_start();
					$this->formclass[$extravaluesk]->show($extravalues2);
					$strfield=ob_get_clean();

					$extravalues['frm_endtagvalue']=$strfield . $extravalues['frm_endtagvalue'];
				}
				$this->formclass[$extravaluesk]->show($extravalues);
				//scrive la chiave primaria una sola volta
				$strhiddenfield="";
			}
			if (isset($extravalues['frm_endgroup']))
			{
				echo $this->formvals[$extravaluesk]['frm_startgroupfooter'] . $extravalues['frm_endgroup'] . $this->formvals[$extravaluesk]['frm_endgroupfooter'];
			}
		}
		$params=false;
	}
	/**
	 * getbypost
	 *
	 * riempe un array con i valori ricevuti tramite post
	 * @param array $oldvalues i valori che non sono in post vanno mantenuti
	 */
	function GetByPost()
	{

		$newvalues=array();
		foreach ($this->formvals as $key=>$value)
		{
			//dprint_r($value);
			if (isset($value['type']) && ($value['type'] == 'check'))
			{
				if (isset($_POST["__check__$key"]) && !isset($_POST["$key"]))
				{
					$newvalues[$key]="";
				}
				if (isset($_POST["__check__$key"]) && isset($_POST[$key]))
				{
					$newvalues[$key]=$_POST[$key];
				}
			}
			else
			if (isset($value['type']) && ($value['type'] == 'image' || $value['type'] == 'file') && isset($_FILES[$key]['name']))
			{

				if (isset($_POST["__isnull__$key"]) && $_POST["__isnull__$key"] == "null")
				{
					$newvalues[$key]="";
				}
				else
				if ($_FILES[$key]['name'] != "")
				{
					$newvalues[$key]=$_FILES[$key]['name'];
					if (ini_get('magic_quotes_gpc') == 1)
					{
						$newvalues[$key]=stripslashes($newvalues[$key]);
					}
				}
			}
			else
			{
				if (isset($_POST[$key]))
				{
					$newvalues[$key]=$_POST[$key];
					if (ini_get('magic_quotes_gpc') == 1)
					{
						$newvalues[$key]=stripslashes($newvalues[$key]);
					}
					if (isset($value['frm_allowhtml']) && $value['frm_allowhtml'] != "true")
					{
						$newvalues[$key]=htmlentities($_POST[$key]);
					}
				}
			}
		}
		return $newvalues;
	}
	function GetQueryByPost()
	{
		$post=$this->GetSearchByPost();
		//dprint_r($post);
		$query="SELECT * FROM {$this->table} WHERE ";
		$sep="";
		foreach ($this->formvals as $key=>$value)
		{
			$mode=isset($post['_search_' . $key]) ? $post['_search_' . $key] : "";
			if (!empty($value['frm_search']) && $mode != "")
			{
				if ($mode == "x_")
				{
					$query .= " $key LIKE '{$post[$key]}%'";
					$sep=" AND ";
				}
				if ($mode == "_x_")
				{
					$query .= "$sep $key LIKE '%{$post[$key]}%'";
					$sep=" AND ";
				}
				if ($mode == "_x")
				{
					$query .= "$sep $key LIKE '%{$post[$key]}'";
					$sep=" AND ";
				}
				if ($mode == "x")
				{
					$query .= "$sep $key LIKE '{$post[$key]}'";
					$sep=" AND ";
				}
				if ($mode == ">")
				{
					$query .= "$sep $key > '{$post[$key]}'";
					$sep=" AND ";
				}
				if ($mode == "<")
				{
					$query .= "$sep $key < '{$post[$key]}'";
					$sep=" AND ";
				}
				
				if (!empty($post[$key]) && !empty($post['_search_range_end_' . $key]) && $mode == "range")
				{
					$query .= "$sep ($key >= '{$post[$key]}' AND $key <= '" . $post['_search_range_end_' . $key] . "')";
					$sep=" AND ";
				}
			}
		}
		return $query;
	}
	/**
	 * getbypost
	 *
	 * riempe un array con i valori ricevuti tramite post
	 * @param array $oldvalues i valori che non sono in post vanno mantenuti
	 */
	function GetSearchByPost()
	{

		$newvalues=array();
		foreach ($_POST as $key=>$value)
		{
			$newvalues[$key]=$value;
		}
		foreach ($this->formvals as $key=>$value)
		{
			if (isset($value['type']) && ($value['type'] == 'check'))
			{
				if (isset($_POST["__check__$key"]) && !isset($_POST["$key"]))
				{
					$newvalues[$key]="";
				}
				if (isset($_POST["__check__$key"]) && isset($_POST[$key]))
				{
					$newvalues[$key]=$_POST[$key];
				}
			}
			else
			{
				if (isset($_POST[$key]))
				{
					$newvalues[$key]=$_POST[$key];
					if (ini_get('magic_quotes_gpc') == 1)
					{
						$newvalues[$key]=stripslashes($newvalues[$key]);
					}
					if (isset($value['frm_allowhtml']) && $value['frm_allowhtml'] != "true")
					{
						$newvalues[$key]=htmlentities($_POST[$key]);
					}
				}
			}
		}
		return $newvalues;
	}
	/**
	 *
	 * @param array $newvalues
	 * @return array
	 */
	function InsertRecord($newvalues)
	{
		foreach ($newvalues as $k=>$v)
		{
			if (method_exists($this->formclass[$k],"formtovalue"))
			{
				$newvalues[$k]=$this->formclass[$k]->formtovalue($v,$this->formvals[$k]);
			}
		}
		return $this->xmltable->InsertRecord($newvalues);
	}
	/**
	 *
	 * @param array $newvalues
	 * @param strung $pkvalue
	 * @return array
	 */
	function UpdateRecord($newvalues,$pkvalue = false)
	{
		foreach ($newvalues as $k=>$v)
		{
			if (isset($this->formclass[$k]) && method_exists($this->formclass[$k],"formtovalue"))
			{
				$newvalues[$k]=$this->formclass[$k]->formtovalue($v,$this->formvals[$k]);
			}
		}
		return $this->xmltable->UpdateRecord($newvalues,$pkvalue);
	}
	/**
	 *
	 * @param string $newvalues
	 * @param bool $update
	 * @return array
	 */
	function VerifyExt($newvalues,$update = false)
	{
		$err="";
		$ret=array();
		foreach ($this->formvals as $key=>$value)
		{
			$err="";
			if ($value['type'] == 'image' && isset($_FILES[$key]['tmp_name']) && $_FILES[$key]['tmp_name'] != "")
			{
				if (!function_exists("getimagesize"))
					$err .= _FNNOGDINSTALL;
				if (!@ getimagesize($_FILES[$key]['tmp_name']))
					$err .= $this->messages["_XMLDBNOTVALIDIMAGE"];
				if (isset($value['frm_maximagesize']) && $value['frm_maximagesize'] != "")
				{
					list($width,$height)=getimagesize($_FILES[$key]['tmp_name']);
					if ($width > $value['frm_maximagesize'] || $height > $value['frm_maximagesize'])
						$err .= $this->messages["_XMLDBTOOBIG"] . " " . $value['frm_maximagesize'] . " pixels";
				}
			}
			if (isset($value['frm_required']) && $value['frm_required'] == 1 && (!isset($newvalues[$key]) || trim($newvalues[$key]) == ""))
			{
				$err .= $this->messages["_XMLDBREQUIRED"];
			}
			if (isset($value['frm_required_condition']) && $value['frm_required_condition'] != "")
			{
				$cond_=preg_replace("/(\\w+)( = )/",'isset($newvalues[\'${1}\']) && \$newvalues[\'${1}\'] == ',trim(ltrim($value['frm_required_condition'])));
				$cond_=preg_replace("/(\\w+)( > )/",'isset($newvalues[\'${1}\']) && \$newvalues[\'${1}\'] > ',trim(ltrim($cond_)));
				$cond_=preg_replace("/(\\w+)( < )/",'isset($newvalues[\'${1}\']) && \$newvalues[\'${1}\'] < ',trim(ltrim($cond_)));
				$req=false;
				eval("if ($cond_){\$req=true;}");
				if ($req == true && (!isset($newvalues[$key]) || trim($newvalues[$key]) == ""))
					$err .= $this->messages["_XMLDBREQUIRED"];
			}
			if ($update == false && ((isset($value['primarykey']) && $value['primarykey'] == 1) || (isset($value['unique']) && $value['unique'] == 1)))
			{
				if (!isset($value['extra']) || $value['extra'] != "autoincrement")
				{
					$restr=array();
					$restr[$key]=$newvalues[$key];
					$t=$this->xmltable->GetRecords($restr);
					if (is_array($t) && count($t) > 0)
					{
						$err .= $this->messages["_XMLDBEXISTS"];
					}
				}
			}
			if (isset($value['frm_retype']) && $value['frm_retype'] == 1)
			{
				if (isset($_POST[$key . "_retype"]) && isset($_POST[$key]))
					if (($_POST[$key] != "" && $_POST[$key] != $_POST[$key . "_retype"]) || ($_POST[$key . "_retype"] != "" && $_POST[$key . "_retype"] != $_POST[$key]))
						$err .= $this->messages["_XMLDBERRORRETYPE"];
			}
			if (isset($value['frm_validator']) && $value['frm_validator'] != "")
			{
				if (isset($newvalues[$key]) && $newvalues[$key] != "" || (isset($value['frm_validateifnull']) && $value['frm_validateifnull'] == 1)) // chiamo la funzione di validazione del campo
					if (function_exists($value['frm_validator']))
						if (($retvalidator=$value['frm_validator']($newvalues[$key])) == false)
						{
							$err .= $this->messages["_XMLDBNOTVALIDFIED"];
						}
						else
						{
							if (is_string($retvalidator))
							{
								$err .= $retvalidator;
							}
						}
			}
			if ($err != "")
			{
				$ret[$key]['title']=$value['title'];
				$ret[$key]['field']=$key;
				$ret[$key]['error']=$err;
			}
		}
		return $ret;
	}
	/**
	 *
	 * @param array $newvalues
	 * @param bool $update
	 * @return string
	 */
	function Verify($newvalues,$update = false)
	{
		$err="";
		foreach ($this->formvals as $key=>$value)
		{
			if ($value['type'] == 'image' && isset($_FILES[$key]['tmp_name']) && $_FILES[$key]['tmp_name'] != "")
			{
				if (!function_exists("getimagesize"))
					$err .= _FNNOGDINSTALL;
				if (!@ getimagesize($_FILES[$key]['tmp_name']))
					$err .= "<b>" . $_FILES[$key]['name'] . "</b>: " . $this->messages["_XMLDBNOTVALIDIMAGE"] . "<br />";
				if (isset($value['frm_maximagesize']) && $value['frm_maximagesize'] != "")
				{
					list($width,$height)=getimagesize($_FILES[$key]['tmp_name']);
					if ($width > $value['frm_maximagesize'] || $height > $value['frm_maximagesize'])
						$err .= "<b>" . $_FILES[$key]['name'] . "</b>:" . $this->messages["_XMLDBTOOBIG"] . " " . $value['frm_maximagesize'] . " pixels" . "<br />";
				}
			}
			if (isset($value['frm_required']) && $value['frm_required'] == 1 && (!isset($newvalues[$key]) || trim($newvalues[$key]) == ""))
			{
				$err .= "<b>" . $value['title'] . ":</b> " . $this->messages["_XMLDBREQUIRED"] . "<br />";
			}
			if (isset($value['frm_required_condition']) && $value['frm_required_condition'] != "")
			{
				$cond_=preg_replace("/(\\w+)( = )/",'isset($newvalues[\'${1}\']) && \$newvalues[\'${1}\'] == ',trim(ltrim($value['frm_required_condition'])));
				$cond_=preg_replace("/(\\w+)( > )/",'isset($newvalues[\'${1}\']) && \$newvalues[\'${1}\'] > ',trim(ltrim($cond_)));
				$cond_=preg_replace("/(\\w+)( < )/",'isset($newvalues[\'${1}\']) && \$newvalues[\'${1}\'] < ',trim(ltrim($cond_)));
				$req=false;
				eval("if ($cond_){\$req=true;}");
				if ($req == true && (!isset($newvalues[$key]) || trim($newvalues[$key]) == ""))
					$err .= "<b>" . $value['title'] . ":</b> " . $this->messages["_XMLDBREQUIRED"] . "<br />";
			}
			if ($update == false && ((isset($value['primarykey']) && $value['primarykey'] == 1) || (isset($value['unique']) && $value['unique'] == 1)))
			{
				if (!isset($value['extra']) || $value['extra'] != "autoincrement")
				{
					$restr=array();
					$restr[$key]=$newvalues[$key];
					$t=$this->xmltable->GetRecords($restr);
					if (is_array($t) && count($t) > 0)
					{
						$err .= "<b>" . $value['title'] . "</b>: " . $newvalues[$key] . " " . $this->messages["_XMLDBEXISTS"] . "<br />";
					}
				}
			}
			if (isset($value['frm_retype']) && $value['frm_retype'] == 1)
			{
				if (($_POST[$key] != "" && $_POST[$key] != $_POST[$key . "_retype"]) || ($_POST[$key . "_retype"] != "" && $_POST[$key . "_retype"] != $_POST[$key]))
					$err .= "<b>" . $value['title'] . "</b>: " . $this->messages["_XMLDBERRORRETYPE"] . "<br />";
			}
			if (isset($value['frm_validator']) && $value['frm_validator'] != "")
			{
				if (isset($newvalues[$key]) && $newvalues[$key] != "" || (isset($value['frm_validateifnull']) && $value['frm_validateifnull'] == 1)) // chiamo la funzione di validazione del campo
				{
					if (function_exists($value['frm_validator']))
					{
						if (($retvalidator=$value['frm_validator']($newvalues[$key])) == false)
						{
							$err .= "<b>" . $value['title'] . "</b>: " . $this->messages["_XMLDBNOTVALIDFIED"] . "<br />";
						}
						else
						{
							if (is_string($retvalidator))
							{
								$err .= "<b>" . $value['title'] . ":</b>" . " " . $retvalidator . "<br />";
							}
						}
					}
				}
			}
		}
		return $err;
	}
	/**
	 * translate record
	 * if field is "record" and lang is "it" replaces it with "record_it"
	 *
	 * @param array $rec
	 * @return array
	 */
	function GetRecordTranslated($rec)
	{
		if (!isset($rec[$this->xmltable->primarykey]))
			return false;
		if (count($rec) != count($this->xmltable->fields))
		{
			$rec=$this->xmltable->GetRecordByPrimaryKey($rec[$this->xmltable->primarykey]);
		}
		if (is_array($rec))
		{
			$tmp=$rec;
			$ret=$rec;
			foreach ($tmp as $key=>$value)
			{
				if (isset($tmp[$key . "_" . $this->lang]) && $tmp[$key . "_" . $this->lang] != "" && isset($this->formvals[$key . "_" . $this->lang]['frm_multilanguage']) && $this->formvals[$key . "_" . $this->lang]['frm_multilanguage'] == 1)
				{
					$ret[$key]=$tmp[$key . "_" . $this->lang];
					unset($ret[$key . "_" . $this->lang]);
				}
			}
			return $ret;
		}
		return null;
	}
}
/**
 * draw languages in form
 *
 * @param array $extravalues
 * @param string $current
 */
function draw_languages($extravalues,$current)
{
	$languagesfield=explode(",",$extravalues['frm_multilanguages']);
	if (isset($languagesfield[0]))
	{
		$langdefault=$languagesfield[0];
		foreach ($languagesfield as $tl)
		{
			$suffix=($tl != $langdefault) ? "_$tl" : "";
			$iddiv1="__frmdb_" . $extravalues['realname'] . "$suffix";
			$jsdb="document.getElementById('$iddiv1').style.height='auto'";
			$jsdb .= ";document.getElementById('$iddiv1').style.width='auto'";
			foreach ($languagesfield as $tl2)
			{
				$suffix2=($tl2 != $langdefault) ? "_$tl2" : "";
				if ($suffix2 != $suffix)
				{
					$iddiv="__frmdb_" . $extravalues['realname'] . "$suffix2";
					$jsdb .= ";document.getElementById('img_$iddiv').style.borderStyle='outset'";
					$jsdb .= ";document.getElementById('$iddiv').style.height='1px'";
					$jsdb .= ";document.getElementById('img_$iddiv').style.opacity='.5'";
					$jsdb .= ";document.getElementById('$iddiv').style.width='1px'";
				}
			}
			$opacity="1";
			$opacity=($current != $tl) ? ".5" : "1";
			$border=($current != $tl) ? "outset" : "inset";

			echo "<button title=\"{$extravalues['title']} : $tl\" style=\"border:2px $border;padding:1px;margin:1px;opacity:$opacity\"  id=\"img_$iddiv1\" onclick=\"$jsdb;document.getElementById('img_$iddiv1').style.opacity='1';document.getElementById('img_$iddiv1').style.borderStyle='inset';return false;\">" . xmldb_get_lang_img_local($tl) . "</button>";
		}
	}
}
/**
 * xmldb_get_lang_img
 * return the html of selected language
 *
 * @param string $lang
 * @return string
 */
function xmldb_get_lang_img_local($lang)
{
	if (function_exists("xmldb_get_lang_img"))
		return xmldb_get_lang_img($lang);
	return "$lang";
}
//---------------------print fields------------------------------------------
/**
 * xmldbform_print_field_text
 * show text field
 *
 */
function xmldbform_print_field_text($name,$value,$rows,$cols,$tooltip)
{
	if (function_exists("xmldbform_print_field_text_overwrite"))
		return call_user_func("xmldbform_print_field_text_overwrite",$name,$value,$rows,$cols,$tooltip);
	$onkeyup="";
	if ($rows == "auto")
	{
		$onkeyup="onkeyup=\"if (this.scrollHeight >= this.offsetHeight){ this.style.height = 10 + this.scrollHeight+'px';}\" ";
		$onkeyup .= "onfocus=\"if (this.scrollHeight >= this.offsetHeight){ this.style.height = 10 + this.scrollHeight+'px';}\" ";
		$onkeyup .= "style=\"overflow:auto;height:30px;\"";
		$rows=3;
	}
	echo "<textarea $onkeyup title=\"$tooltip\" cols=\"" . $cols . "\"  rows=\"" . $rows . "\"  name=\"$name\"  >";
	echo htmlspecialchars($value);
	echo "</textarea>";
	return false;
}
/**
 * xmldbforn_field_string
 * show string field
 *
 */
function xmldbforn_field_string($name,$value,$size,$tooltip)
{
	if (function_exists("xmldbforn_field_string_overwrite"))
		return call_user_func("xmldbforn_field_string_overwrite",$name,$value,$size,$tooltip);
	echo "<input title=\"$tooltip\" size=\"" . $size . "\" name=\"$name\"  value=\"" . str_replace('"','&quot;',$value) . "\" />";
	return false;
}
/**
 * xmldbform_print_field_html
 * show html field
 *
 */
function xmldbform_print_field_html($name,$value,$rows,$cols,$tooltip)
{
	if (function_exists("xmldbform_print_field_html_overwrite"))
		return xmldbform_print_field_html_overwrite($name,$value,$rows,$cols,$tooltip);
	echo "<textarea title=\"$tooltip\" cols=\"" . $cols . "\"  rows=\"" . $rows . "\"  name=\"$name\"  >";
	echo htmlspecialchars($value);
	echo "</textarea>";
	return false;
}
/**
 * fields
 *
 *
 */
class xmldbform_field_separator
{
	function xmldbform_field_separator()
	{
		
	}
	function show($params)
	{
		$this->starttagtitle=isset($params['frm_starttagtitle']) ? $params['frm_starttagtitle'] : "<tr><td  valign=\"top\" >";
		$this->endtagtitle=isset($params['frm_endtagtitle']) ? $params['frm_endtagtitle'] : "</td>";
		$this->starttagvalue=isset($params['frm_starttagvalue']) ? $params['frm_starttagvalue'] : "<td valign=\"top\" >";
		$this->endtagvalue=isset($params['frm_endtagvalue']) ? $params['frm_endtagvalue'] : "</td></tr>";
		$strhiddenfield=$params['strhiddenfield'];
		echo $this->starttagtitle;
		echo "$strhiddenfield" . $params['title'];
		echo $this->endtagtitle;
		echo $this->starttagvalue;
		echo $this->endtagvalue;
	}
}
//---------string--------------------------------------->
class xmldbform_field_varchar
{
	function xmldbform_field_varchar()
	{
		
	}
	function show($params)
	{
		$this->starttagtitle=isset($params['frm_starttagtitle']) ? $params['frm_starttagtitle'] : "<tr><td  valign=\"top\" >";
		$this->endtagtitle=isset($params['frm_endtagtitle']) ? $params['frm_endtagtitle'] : "</td>";
		$this->starttagvalue=isset($params['frm_starttagvalue']) ? $params['frm_starttagvalue'] : "<td valign=\"top\" >";
		$this->endtagvalue=isset($params['frm_endtagvalue']) ? $params['frm_endtagvalue'] : "</td></tr>";
		$toltips=($params['frm_help'] != "") ? "title=\"" . $params['frm_help'] . "\"" : "";
		$strhiddenfield=$params['strhiddenfield'];
		$size=isset($params['frm_size']) ? $params['frm_size'] : 30;
		echo $this->starttagtitle . $params['title'] . $this->endtagtitle;
		echo $this->starttagvalue;
		echo $strhiddenfield;
//-----------------------------------------
		$languagesfield=$params['languagesfield'];
		$lang_noprefix=$params['lang_noprefix'];
//$lang_user = $params ['lang_user'];
		$oldvalues=$params['oldvalues'];
		if ($params['multilanguage'])
		{
			//echo "<div style=\"position:relative\" >";
			echo "<table style=\"border:0px;padding:0px\" cellpadding=\"0\" cellspacing=\"0\" border=\"0\"><tr><td>";
			draw_languages($params,$params['lang']);
			$margin=0;
			foreach ($languagesfield as $tl)
			{
				$suffix=($tl != $lang_noprefix) ? "_$tl" : "";
				if ($tl != $params['lang_user'])
				{
					if (!isset($oldvalues[$params['realname'] . $suffix]))
						$oldvalues[$params['realname'] . $suffix]="";
					echo "\n<div style=\"background-color:transparent;border:0px;padding:0px;margin:{$margin}px;display:block;overflow:hidden;height:1px;width:1px;\" id=\"__frmdb_" . $params['realname'] . "$suffix" . "\" >";
					xmldbforn_field_string($params['realname'] . $suffix,$oldvalues[$params['realname'] . $suffix],$size,$params['frm_help']);
					echo "\n" . xmldb_get_lang_img_local($tl) . "</div>\n";
				}
				else
				{
					echo "\n<div style=\"background-color:transparent;border:0px;padding:0px;margin:{$margin}px;display:block;overflow:hidden;\" id=\"__frmdb_" . $params['name'] . "\" >";
					xmldbforn_field_string($params['name'],$params['value'],$size,$params['frm_help']);
					echo "\n" . xmldb_get_lang_img_local($params['lang_user']) . "";
					echo "</div>";
				}
				//$margin --;
			}
			echo "</td></tr></table>";
			//echo "</div>";
		}
		else
		{
			xmldbforn_field_string($params['name'],$params['value'],$size,$params['frm_help']);
		}
//-----------------------------------------
		echo $this->endtagvalue;
		if (isset($params['frm_retype']) && $params['frm_retype'] == 1)
		{
			echo $this->starttagtitle;
			echo $params['title'] . " (" . $params['messages']["_XMLDBRETYPE"] . ")";
			echo $this->endtagtitle;
			echo $this->starttagvalue;
			echo "\n<input $toltips value=\"" . str_replace('"','&quot;',$params['value']) . "\" name=\"" . $params['name'] . "_retype\" retype\" type=\"text\" />\n";
			echo $this->endtagvalue;
		}
	}
}
//---------string---------------------------------------<
//---------password--------------------------------------->
class xmldbform_field_password
{
	function xmldbform_field_password()
	{
		
	}
	function show($params)
	{
		$this->starttagtitle=isset($params['frm_starttagtitle']) ? $params['frm_starttagtitle'] : "<tr><td  valign=\"top\" >";
		$this->endtagtitle=isset($params['frm_endtagtitle']) ? $params['frm_endtagtitle'] : "</td>";
		$this->starttagvalue=isset($params['frm_starttagvalue']) ? $params['frm_starttagvalue'] : "<td valign=\"top\" >";
		$this->endtagvalue=isset($params['frm_endtagvalue']) ? $params['frm_endtagvalue'] : "</td></tr>";
		$toltips=($params['frm_help'] != "") ? "title=\"" . $params['frm_help'] . "\"" : "";
		$strhiddenfield=$params['strhiddenfield'];
		echo $this->starttagtitle;
		echo $params['title'];
		echo $this->endtagtitle;
		echo $this->starttagvalue;
		echo "$strhiddenfield<input $toltips value=\"\" autocomplete=\"off\" name=\"" . $params['name'] . "\" type=\"password\" />\n";
		echo $this->endtagvalue;
		if (isset($params['frm_retype']) && $params['frm_retype'] == 1)
		{
			echo $this->starttagtitle;
			echo $params['title'] . " (" . $params['messages']["_XMLDBRETYPE"] . ")";
			echo $this->endtagtitle;
			echo $this->starttagvalue;
			echo "<input name=\"" . $params['name'] . "_retype\"  autocomplete=\"off\" value=\"\" type=\"password\" />";
			echo $this->endtagvalue;
		}
	}
}
//---------password---------------------------------------<
//---------select--------------------------------------->
class xmldbform_field_select
{
	function xmldbform_field_select()
	{
		
	}
	function show($params)
	{
		$this->starttagtitle=isset($params['frm_starttagtitle']) ? $params['frm_starttagtitle'] : "<tr><td  valign=\"top\" >";
		$this->endtagtitle=isset($params['frm_endtagtitle']) ? $params['frm_endtagtitle'] : "</td>";
		$this->starttagvalue=isset($params['frm_starttagvalue']) ? $params['frm_starttagvalue'] : "<td valign=\"top\" >";
		$this->endtagvalue=isset($params['frm_endtagvalue']) ? $params['frm_endtagvalue'] : "</td></tr>";
		$toltips="";
		$strhiddenfield=$params['strhiddenfield'];
		$extravalues=$params;
		echo $this->starttagtitle;
		echo $params['title'];
		echo $this->endtagtitle;
		echo $this->starttagvalue;
		echo "\n$strhiddenfield";
		$script="";
		$scriptfirst="";
		$optionname="";
		$divid="";
		if (isset($extravalues['frm_show_image']) && $extravalues['frm_show_image'] != "")
		{
			$divid="fkimg_" . $extravalues['name'];
			$script="onchange=\"this.options[this.selectedIndex].onfocus()\"";
			$script .= " onkeyup=\"this.options[this.selectedIndex].onfocus()\"";
			$scriptfirst="onfocus=\"document.getElementById('$divid').innerHTML = ''\"";
		}
		echo "<select $toltips $script name=\"" . $extravalues['name'] . "\" type=\"text\" />";
		echo "\n<option $scriptfirst";
		echo " label=\"\" name=\"$optionname\" value=\"\">----</option>";
		$options=array();
		$optionselected=null;
		$oldvalimage="";
		if (isset($extravalues['options']) && is_array($extravalues['options']))
			foreach ($extravalues['options'] as $option)
			{
				$options[$option['value']]['name']=$option['title'];
				$options[$option['value']]['value']=$option['value'];
				if ($option['value'] === $extravalues['value'])
				{
					$optionselected=$option['value'];
				}
				if (isset($extravalues['frm_show_image']) && $extravalues['frm_show_image'] != "")
				{
					$options[$option['value']]['image']=$option['frm_show_image'];
					$options[$option['value']]['thumbsize']=isset($option['thumbsize']) ? $option['thumbsize'] + 3 : 0;
				}
			}
		$options=xmldb_array_sort_by_key($options,"name");
		$himg=0;
		foreach ($options as $option)
		{
			$optionname=$jj="";
			if (isset($option['image']) && $option['image'] != "")
				$optionname="<img src='" . $option['image'] . "' alt='' />";
			if ($option['value'] == $optionselected)
			{
				$selected=" selected=\"select\" ";
				$oldvalimage=$optionname;
			}
			else
				$selected="";
			if (isset($option['thumbsize']) && $option['thumbsize'] > $himg)
			{
				$himg=$option['thumbsize'];
			}
			if ($divid != "")
				$jj="onfocus=\"document.getElementById('$divid').innerHTML = '" . addslashes($optionname) . "';\"";
			echo "\n\t<option $selected $jj value=\"" . $option['value'] . "\" >" . $option['name'] . "</option>";
		}
		echo "\n</select>\n";
		if (isset($extravalues['frm_show_image']) && $extravalues['frm_show_image'] != "")
		{
			echo "<div style=\"height:$himg" . "px;overflow:auto\" id=\"$divid\">" . $oldvalimage . "</div>";
		}
		//-----filtro su altro elemento----->
		if (isset($extravalues['fk_filter_field']) && $extravalues['fk_filter_field'] != "")
		{
			$clausule=explode("=",$extravalues['fk_filter_field']);
			if (isset($clausule[1]))
			{
				//prende tutte le clausule separate da virgola
				$clausules=explode(",",$extravalues['fk_filter_field']);
				$restr=array();
				foreach ($clausules as $claus_item)
				{
					$clausule=explode("=",$claus_item);
					if (isset($clausule[1]))
					{
						$cname2=$clausule[1];
						//se e' di tipo pippo='pippo'
						if ($cname2[0] == "'" && $cname2[strlen($cname2) - 1] == "'")
						{
							
						}
						else
						{
							echo "<script language=\"javascript\">
try{
var el{$extravalues['name']}=document.getElementsByName('{$clausule[1]}')[0];
var options=document.getElementsByName('{$extravalues['name']}')[0];
el{$extravalues['name']}.onchange=function()
{
	var inp;
	inp = document.createElement('input');
	inp.type='submit';
	inp.name='';
	inp.value='loading';

	var div;
	div = document.createElement('div');
	div.innerHTML='loading...';
	try{
		div.style.backgroundColor='#000000';
		div.style.color='#ffffff';
		div.style.display='block';
		div.style.position='absolute';
		div.style.width='100%';
		div.style.height='100%';
		div.style.top='0px';
		div.style.left='0px';
		div.style.opacity='0.8';
		div.style.filter='alpha(opacity=80)';
		inp.style.position='absolute';
		inp.style.height='0px';
		inp.style.width='0px';
		inp.style.overflow='hidden';
	}
	catch(e)
	{
       // alert(e);
	}
	el{$extravalues['name']}.parentNode.appendChild(inp);
	inp.click();
	document.getElementsByTagName('body')[0].appendChild(div);
}
}catch (e){
    // alert(e);
    }
</script>";
						}
					}
				}
			}
		}
//-----filtro su altro elemento-----<
		echo $this->endtagvalue;
	}
}
//---------select---------------------------------------<
//---------file--------------------------------------->
class xmldbform_field_file
{
	function xmldbform_field_file()
	{
		
	}
	function show($params)
	{
		$this->starttagtitle=isset($params['frm_starttagtitle']) ? $params['frm_starttagtitle'] : "<tr><td  valign=\"top\" >";
		$this->endtagtitle=isset($params['frm_endtagtitle']) ? $params['frm_endtagtitle'] : "</td>";
		$this->starttagvalue=isset($params['frm_starttagvalue']) ? $params['frm_starttagvalue'] : "<td valign=\"top\" >";
		$this->endtagvalue=isset($params['frm_endtagvalue']) ? $params['frm_endtagvalue'] : "</td></tr>";
		$toltips="";
		$strhiddenfield=$params['strhiddenfield'];
		$size=isset($params['frm_size']) ? $params['frm_size'] : 20;
		$oldvalues=$params['oldvalues'];
		$oldval=$params['value'];
		$primarykey=$params['oldvalues_primarikey'];
		echo $this->starttagtitle . $params['title'] . $this->endtagtitle;
		echo $this->starttagvalue;
		echo "$strhiddenfield<input $toltips size=\"$size\" name=\"" . $params['name'] . "\" type=\"file\" />\n";
		echo "<br />";
		//dprint_r($params);
		if ($oldval != "")
		{
			$tablepath=$params['fieldform']->xmltable->FindFolderTable($oldvalues);
			echo "<br /><a href=\"" . $params['fieldform']->path . "/" . $params['fieldform']->databasename . "/$tablepath/" . $oldvalues[$primarykey] . "/" . $params['name'] . "/$oldval\" >$oldval</a>";
			echo "<input $toltips type=\"checkbox\" value=\"null\" name=\"__isnull__" . $params['name'] . "\" />" . $params['messages']["_XMLDBDELETE"];
		}
		echo $this->endtagvalue;
	}
}
//---------file---------------------------------------<
//---------image--------------------------------------->
class xmldbform_field_image
{
	function xmldbform_field_image()
	{
		
	}
	function show($params)
	{
		$this->starttagtitle=isset($params['frm_starttagtitle']) ? $params['frm_starttagtitle'] : "<tr><td  valign=\"top\" >";
		$this->endtagtitle=isset($params['frm_endtagtitle']) ? $params['frm_endtagtitle'] : "</td>";
		$this->starttagvalue=isset($params['frm_starttagvalue']) ? $params['frm_starttagvalue'] : "<td valign=\"top\" >";
		$this->endtagvalue=isset($params['frm_endtagvalue']) ? $params['frm_endtagvalue'] : "</td></tr>";
		$oldvalues=$params['oldvalues'];
		$primarykey=$params['oldvalues_primarikey'];
		$oldval=$params['value'];
		$toltips="";
		$strhiddenfield=$params['strhiddenfield'];
		$size=isset($params['frm_size']) ? $params['frm_size'] : 20;
		$tsize=isset($params['thumbsize']) ? $params['thumbsize'] : 20;
		echo $this->starttagtitle . $params['title'] . $this->endtagtitle;
		echo $this->starttagvalue;
		echo "$strhiddenfield<table style=\"border:0px;padding:0px\" cellpadding=\"0\" cellspacing=\"0\"><tr><td><input $toltips size=\"" . $size . "\" name=\"" . $params['name'] . "\" type=\"file\" />\n";
		echo "<br />";
//dprint_r($oldval);
//dprint_r($this->path."/".$this->databasename."/".$this->tablename."/".$oldvalues[$primarykey]."/thumbs/$oldval.jpg");
		if ($oldval != "" && isset($oldvalues[$primarykey]))
		{
			$width=$height="";
			$tablepath=$params['fieldform']->xmltable->FindFolderTable($oldvalues);
			$imgthsrc=$params['fieldform']->path . "/" . $params['fieldform']->databasename . "/" . $tablepath . "/" . $oldvalues[$primarykey] . "/" . $params['name'] . "/thumbs/$oldval.jpg";
			if (!file_exists($imgthsrc))
				$imgthsrc=$params['fieldform']->path . "/" . $params['fieldform']->databasename . "/" . $tablepath . "/" . $oldvalues[$primarykey] . "/" . $params['name'] . "/$oldval";
			if (file_exists($imgthsrc))
				list($width,$height)=getimagesize($imgthsrc);
			if ($height >= $width)
				$res="height=\"$tsize\"";
			else
				$res="width=\"$tsize\"";
			echo "<table cellpadding=\"0\" cellspacing=\"0\" style=\"border:1px dotted;height:$tsize" . "px;width:$tsize" . "px\"><tr><td valign=\"center\"><img style=\"vertical-align: middle;\" $res src=\"$imgthsrc\" alt=\"$oldval\" border=\"0\" />";
			echo "<nobr><input $toltips type=\"checkbox\" value=\"null\" name=\"__isnull__" . $params['name'] . "\" />" . $params['messages']["_XMLDBDELETE"];
			echo "</nobr></td></tr></table>";
		}
		echo "</td></tr></table>";
		echo $this->endtagvalue;
	}
}
//---------image---------------------------------------<
//---------textarea--------------------------------------->
class xmldbform_field_text
{
	function xmldbform_field_text()
	{
		
	}
	function show($params)
	{
		$this->starttagtitle=isset($params['frm_starttagtitle']) ? $params['frm_starttagtitle'] : "<tr><td  valign=\"top\" >";
		$this->endtagtitle=isset($params['frm_endtagtitle']) ? $params['frm_endtagtitle'] : "</td>";
		$this->starttagvalue=isset($params['frm_starttagvalue']) ? $params['frm_starttagvalue'] : "<td valign=\"top\" >";
		$this->endtagvalue=isset($params['frm_endtagvalue']) ? $params['frm_endtagvalue'] : "</td></tr>";
		$rows=isset($params['frm_rows']) ? $params['frm_rows'] : 4;
		$cols=isset($params['frm_cols']) ? $params['frm_cols'] : 20;
		$strhiddenfield=$params['strhiddenfield'];
		$languagesfield=$params['languagesfield'];
		$lang_noprefix=$params['lang_noprefix'];
//$lang_user = $params ['lang_user'];
		$oldvalues=$params['oldvalues'];
		$tooltip=$params['frm_help'];
		echo $this->starttagtitle . $params['title'] . $this->endtagtitle;
		echo $this->starttagvalue;
		echo $strhiddenfield;
		if ($params['multilanguage'])
		{
			echo "<table height=\"0\" style=\"border:0px;padding:0px\" cellpadding=\"0\" cellspacing=\"0\"  border=\"0\"><tr><td>";
			draw_languages($params,$params['lang']);
			echo "\n<div style=\"display:block;overflow:hidden\" id=\"__frmdb_" . $params['name'] . "\" >";
		}
		xmldbform_print_field_text($params['name'],$params['value'],$rows,$cols,$tooltip);
		if ($params['multilanguage'])
		{
			echo "<br />\n" . xmldb_get_lang_img_local($params['lang_user']) . "";
			echo "</div>";
		}
		if ($params['multilanguage'])
		{
			foreach ($languagesfield as $tl)
			{
				$suffix=($tl != $lang_noprefix) ? "_$tl" : "";
				if ($tl != $params['lang_user'])
				{
					if (!isset($oldvalues[$params['realname'] . $suffix]))
						$oldvalues[$params['realname'] . $suffix]="";
					echo "\n<div style=\"display:block;overflow:hidden;height:1px;width:1px;\" id=\"__frmdb_" . $params['realname'] . "$suffix" . "\" >";
					xmldbform_print_field_text($params['realname'] . $suffix,$oldvalues[$params['realname'] . $suffix],$rows,$cols,$params['frm_help']);
					echo "<br />\n" . xmldb_get_lang_img_local($tl) . "</div>\n";
				}
			}
		}
		if ($params['multilanguage'])
			echo "</td></tr></table>";
		echo $this->endtagvalue;
	}
}
//---------textarea---------------------------------------<
//---------html--------------------------------------->
class xmldbform_field_html
{
	function xmldbform_field_html()
	{
		
	}
	function show($params)
	{
		$this->starttagtitle=isset($params['frm_starttagtitle']) ? $params['frm_starttagtitle'] : "<tr><td  valign=\"top\" >";
		$this->endtagtitle=isset($params['frm_endtagtitle']) ? $params['frm_endtagtitle'] : "</td>";
		$this->starttagvalue=isset($params['frm_starttagvalue']) ? $params['frm_starttagvalue'] : "<td valign=\"top\" >";
		$this->endtagvalue=isset($params['frm_endtagvalue']) ? $params['frm_endtagvalue'] : "</td></tr>";
		$rows=isset($params['frm_rows']) ? $params['frm_rows'] : 4;
		$cols=isset($params['frm_cols']) ? $params['frm_cols'] : 20;
		$strhiddenfield=$params['strhiddenfield'];
		$languagesfield=$params['languagesfield'];
		$lang_noprefix=$params['lang_noprefix'];
//$lang_user = $params ['lang_user'];
		$oldvalues=$params['oldvalues'];
//	dprint_r($oldvalues);
		$tooltip=$params['frm_help'];
		echo $this->starttagtitle . $params['title'] . $this->endtagtitle;
		echo $this->starttagvalue;
		echo $strhiddenfield;
		if ($params['multilanguage'])
		{
			echo "<table  style=\"border:0px;padding:0px\" cellpadding=\"0\" cellspacing=\"0\"  border=\"0\"><tr><td>";
			draw_languages($params,$params['lang']);
			echo "\n<div style=\"display:block;overflow:hidden\" id=\"__frmdb_" . $params['name'] . "\" >";
		}
		xmldbform_print_field_html($params['name'],$params['value'],$rows,$cols,$tooltip);
		if ($params['multilanguage'])
		{
			echo "<br />" . xmldb_get_lang_img_local($params['lang_user']) . "";
			echo "</div>";
		}
		if ($params['multilanguage'])
		{
			foreach ($languagesfield as $tl)
			{
				$suffix=($tl != $lang_noprefix) ? "_$tl" : "";
				if ($tl != $params['lang_user'])
				{
					if (!isset($oldvalues[$params['realname'] . $suffix]))
						$oldvalues[$params['realname'] . $suffix]="";
					echo "\n<div style=\"display:block;overflow:hidden;height:1px;width:1px;\" id=\"__frmdb_" . $params['realname'] . "$suffix" . "\" >";
					xmldbform_print_field_html($params['realname'] . $suffix,$oldvalues[$params['realname'] . $suffix],$rows,$cols,$params['frm_help']);
					echo "<br />" . xmldb_get_lang_img_local($tl) . "</div>";
				}
			}
		}
		if ($params['multilanguage'])
		{
			echo "</td></tr></table>";
		}
		echo $this->endtagvalue;
	}
}
//---------html---------------------------------------<
//---------check--------------------------------------->
class xmldbform_field_check
{
	function xmldbform_field_check()
	{
		
	}
	function show($params)
	{
		$this->starttagtitle=isset($params['frm_starttagtitle']) ? $params['frm_starttagtitle'] : "<tr><td  valign=\"top\" >";
		$this->endtagtitle=isset($params['frm_endtagtitle']) ? $params['frm_endtagtitle'] : "</td>";
		$this->starttagvalue=isset($params['frm_starttagvalue']) ? $params['frm_starttagvalue'] : "<td valign=\"top\" >";
		$this->endtagvalue=isset($params['frm_endtagvalue']) ? $params['frm_endtagvalue'] : "</td></tr>";
		$toltips="";
		$strhiddenfield=$params['strhiddenfield'];
//$size = isset ( $params ['frm_size'] ) ? $params ['frm_size'] : 20;
		$oldval=$params['value'];
		echo $this->starttagtitle . $params['title'] . $this->endtagtitle;
		echo $this->starttagvalue;
		$ch="";
		if ($oldval != "")
			$ch="checked=\"checked\"";
		if ($oldval != $params['frm_checkon'])
		{
			$ch="";
		}
		echo "\n$strhiddenfield ";
		echo "<input type=\"hidden\" value=\"" . htmlspecialchars($oldval) . "\" name=\"__check__" . $params['name'] . "\"  />";
		echo "<input $toltips $ch type=\"checkbox\" value=\"" . $params['frm_checkon'] . "\" name=\"" . $params['name'] . "\"  />";
		echo $this->endtagvalue;
	}
}
//---------innertable--------------------------------------->
class xmldbform_field_innertable
{
	function xmldbform_field_innertable()
	{
		
	}
	function show($params)
	{
		$this->starttagtitle=isset($params['frm_starttagtitle']) ? $params['frm_starttagtitle'] : "<tr><td  valign=\"top\" >";
		$this->endtagtitle=isset($params['frm_endtagtitle']) ? $params['frm_endtagtitle'] : "</td>";
		$this->starttagvalue=isset($params['frm_starttagvalue']) ? $params['frm_starttagvalue'] : "<td valign=\"top\" >";
		$this->endtagvalue=isset($params['frm_endtagvalue']) ? $params['frm_endtagvalue'] : "</td></tr>";
		$toltips="";
		$strhiddenfield=$params['strhiddenfield'];
//$size = isset ( $params ['frm_size'] ) ? $params ['frm_size'] : 20;
		$oldval=$params['value'];
		echo $this->starttagtitle . $params['title'] . $this->endtagtitle;
		echo $this->starttagvalue;
		$ch="";
		echo "\n$strhiddenfield ";
		echo "TODO";
		echo $this->endtagvalue;
	}
}
//---------innertable---------------------------------------<
?>